@@ -492,6 +492,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
     AbiGOffice_removeFromMenus();
 	go_component_set_command_context (NULL);
 	g_object_unref (cc);
+	go_plugins_shutdown();
+	libgoffice_shutdown();
 
     return 1;
 }
