@@ -2,7 +2,7 @@
  * 
  * Copyright (C) 2005 INdT
  * Author: Daniel d'Andrada T. de Carvalho <daniel.carvalho@indt.org.br>
- * Copyright 2009 AbiSource Corporation B.V.
+ * Copyright 2009-2010 AbiSource Corporation B.V.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,6 +42,7 @@
  * ODe_Style_Style
  ******************************************************************************/
 
+std::map<std::string, std::string> ODe_Style_Style::m_NCStyleMappings;
 
 /**
  * Constructor
@@ -102,21 +103,28 @@ bool ODe_Style_Style::write(GsfOutput* pODT, const UT_UTF8String& rSpacesOffset)
             UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
             return false;
         }
-        escape = m_name;
+        escape = ODe_Style_Style::convertStyleToNCName(m_name);
         output += " style:name=\"";
         output += escape.escapeXML();
         output += "\"";
         
-        escape = m_parentStyleName;
+        escape = m_name;
+        escape.escapeXML();
+        ODe_writeAttribute(output, "style:display-name", escape);
+        
+        escape = ODe_Style_Style::convertStyleToNCName(m_parentStyleName);
         escape.escapeXML();
         ODe_writeAttribute(output, "style:parent-style-name", escape);
-        escape = m_nextStyleName;
+        
+        escape = ODe_Style_Style::convertStyleToNCName(m_nextStyleName);
         escape.escapeXML();
         ODe_writeAttribute(output, "style:next-style-name", escape);
-        escape = m_masterPageName;
+        
+        escape = ODe_Style_Style::convertStyleToNCName(m_masterPageName);
         escape.escapeXML();
         ODe_writeAttribute(output, "style:master-page-name", escape);
-        escape = m_listStyleName;
+        
+        escape = ODe_Style_Style::convertStyleToNCName(m_listStyleName);
         escape.escapeXML();
         ODe_writeAttribute(output, "style:list-style-name", escape);
     }
@@ -288,6 +296,101 @@ bool ODe_Style_Style::hasParagraphStyleProps(const PP_AttrProp* pAP) {
     if (ok && pValue != NULL) {
         return true;
     }
+    
+    ok = pAP->getProperty("shading-pattern", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("shading-foreground-color", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("border-merge", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("bot-color", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("bot-style", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("bot-thickness", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("bot-space", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("left-color", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("left-style", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("left-thickness", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("left-space", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("right-color", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("right-style", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("right-thickness", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("right-space", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("top-color", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("top-style", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("top-thickness", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
+    
+    ok = pAP->getProperty("top-space", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
 
     ok = pAP->getProperty("default-tab-interval", pValue);
     if (ok && pValue != NULL) {
@@ -766,6 +869,7 @@ void ODe_Style_Style::inheritTableCellProperties(const ODe_Style_Style& tableSty
     m_pCellProps->m_topColor = tableStyle.m_pCellProps->m_topColor;
     m_pCellProps->m_bottomThickness = tableStyle.m_pCellProps->m_bottomThickness;
     m_pCellProps->m_bottomColor = tableStyle.m_pCellProps->m_bottomColor;
+    m_pCellProps->m_verticalAlign = tableStyle.m_pCellProps->m_verticalAlign;
 
     // Table background colors are not inherited in AbiWord and an OpenDocument
     // table can have its own background color as well, so we don't inherit
@@ -861,6 +965,43 @@ void ODe_Style_Style::setDefaultTabInterval(const UT_UTF8String& rDefaultTabInte
     m_pParagraphProps->m_defaultTabInterval = rDefaultTabInterval;
 }
 
+/**
+ * 
+ */
+UT_UTF8String ODe_Style_Style::convertStyleToNCName(const UT_UTF8String& name) {
+    // To generate a valid NCName for a style, we simply replace
+    // all non-alphanumeric characters with a dash. Then whenever a collision
+    // occurs between the generated ncnames for two different styles, we'll
+    // just append the string "-1" until it becomes unique :)
+    //
+    // Feel free to make it not replace valid NCName characters. See
+    // http://www.w3.org/TR/REC-xml-names/#NT-NCName for the allowed values
+
+    std::string nc_name = name.utf8_str();
+    for (UT_uint32 i = 0; i < nc_name.size(); i++) {
+        if (isalnum(nc_name[i]))
+            continue;
+        nc_name[i] = '-';
+    }
+    
+    while (true) {
+        if (m_NCStyleMappings.find(nc_name) == m_NCStyleMappings.end()) {
+            // we've never used this nc_name before, so assign it to our style name
+            m_NCStyleMappings[nc_name] = name.utf8_str();
+            return nc_name.c_str();;
+        }
+        
+        if (m_NCStyleMappings[nc_name] == name.utf8_str()) {
+            // we've seen this nc_before and it matches our style name, so 
+            // reuse it!
+            return nc_name.c_str();;
+        }
+        
+        // we've encountered a collision, add "-1" and try again
+        nc_name += "-1";
+    }
+}
+
 
 /*******************************************************************************
  * SectionProps
@@ -983,9 +1124,18 @@ bool ODe_Style_Style::ParagraphProps::isEmpty() const {
              m_marginBottom.empty() &&
              m_keepWithNext.empty() &&
              m_breakBefore.empty() &&
-             m_writingMode.empty() &&
+             m_writingMode.empty()) &&
+             m_borderMerge.empty() &&
+             m_borderLeft.empty() &&
+             m_borderRight.empty() &&
+             m_borderTop.empty() &&
+             m_borderBottom.empty() &&
+             m_botSpace.empty() &&
+             m_leftSpace.empty() &&
+             m_rightSpace.empty() &&
+             m_topSpace.empty() &&
              m_defaultTabInterval.empty() &&
-             m_tabStops.size() == 0);
+             m_tabStops.size() == 0;
 }
 
 /**
@@ -996,15 +1146,30 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     const gchar* pValue;
     bool ok;
     
-    ok = rAP.getProperty("bgcolor", pValue);
-    if (ok && pValue && *pValue) {
-        if (!strcmp("transparent", pValue)) { 
+    ok = rAP.getProperty("shading-foreground-color", pValue);
+    if (ok && pValue && *pValue) 
+    {
+        if (!strcmp("transparent", pValue)) 
+	{ 
             m_backgroundColor = pValue;
-        } else {
+        } 
+	else 
+	{
             m_backgroundColor = UT_colorToHex(pValue, true);
         }
     }
-    
+    ok = rAP.getProperty("shading-pattern", pValue);
+    if (ok && pValue && *pValue) 
+    {
+      if(atoi(pValue) == 0)
+      {
+	  m_backgroundColor = "transparent";
+      }
+    }
+    else if( !m_backgroundColor.empty())
+    {
+	m_backgroundColor = "transparent";
+    }
     ok = rAP.getProperty("line-height", pValue);
     if (ok && pValue != NULL) {
         UT_LocaleTransactor t(LC_NUMERIC, "C");
@@ -1090,6 +1255,141 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
         }
     }
 
+    
+    // Left border
+
+    ok = rAP.getProperty("left-style", pValue);
+	if(!ok || (pValue && (*pValue == '0'))) {
+      m_borderLeft.clear();
+    } else {
+        ok = rAP.getProperty("left-thickness", pValue);
+        if (ok && pValue != NULL) {
+            m_borderLeft = pValue;
+        }
+        
+        ok = rAP.getProperty("left-color", pValue);
+        if (ok && pValue != NULL) {
+            if (!m_borderLeft.empty()) {
+                m_borderLeft += " ";
+            }
+            m_borderLeft += "solid ";
+            m_borderLeft += UT_colorToHex(pValue, true);
+        }
+    }
+    
+    
+    // Right border
+
+    ok = rAP.getProperty("right-style", pValue);
+    if(!ok || (pValue && (*pValue == '0'))) {
+      m_borderRight.clear();
+    } else {
+        ok = rAP.getProperty("right-thickness", pValue);
+        if (ok && pValue != NULL) {
+            m_borderRight = pValue;
+        }
+        
+        ok = rAP.getProperty("right-color", pValue);
+        if (ok && pValue != NULL) {
+            if (!m_borderRight.empty()) {
+                m_borderRight += " ";
+            }
+            m_borderRight += "solid ";
+            m_borderRight += UT_colorToHex(pValue, true);
+        }
+    }
+   
+    
+    // Top border
+    
+    ok = rAP.getProperty("top-style", pValue);
+    if(!ok || (pValue && (*pValue == '0'))) {
+      m_borderTop.clear();
+    } else {
+        ok = rAP.getProperty("top-thickness", pValue);
+        if (ok && pValue != NULL) {
+            m_borderTop = pValue;
+        }
+        
+        ok = rAP.getProperty("top-color", pValue);
+        if (ok && pValue != NULL) {
+            if (!m_borderTop.empty()) {
+                m_borderTop += " ";
+            }
+            m_borderTop += "solid ";
+            m_borderTop += UT_colorToHex(pValue, true);
+        }
+    }
+    
+    
+    // Bottom border
+    
+    ok = rAP.getProperty("bot-style", pValue);
+    if(!ok || (pValue && (*pValue == '0'))) {
+      m_borderBottom.clear();
+    } else {
+        ok = rAP.getProperty("bot-thickness", pValue);
+        if (ok && pValue != NULL) {
+            m_borderBottom = pValue;
+        }
+        
+        ok = rAP.getProperty("bot-color", pValue);
+        if (ok && pValue != NULL) {
+            if (!m_borderBottom.empty()) {
+                m_borderBottom += " ";
+            }
+            
+            m_borderBottom += "solid ";
+            m_borderBottom += UT_colorToHex(pValue, true);
+        }
+    }
+     
+    // Border merge
+
+    ok = rAP.getProperty("border-merge", pValue);
+    if(!ok || (pValue && ((*pValue == '0') || strcmp(pValue, "false") == 0)))
+      m_borderMerge.clear();
+    else
+      m_borderMerge = pValue;
+      
+
+    // padding
+
+    ok = rAP.getProperty("bot-space", pValue);
+    if(!ok)
+      m_botSpace.clear();
+    else
+    {
+      m_botSpace = pValue;
+    }
+
+
+    ok = rAP.getProperty("left-space", pValue);
+    if(!ok)
+      m_leftSpace.clear();
+    else 
+    {
+     UT_DEBUGMSG(("ok %d left-space %s \n",ok,pValue));
+      m_leftSpace = pValue;
+    }
+    UT_DEBUGMSG(("1 -m_leftspace %s \n",m_leftSpace.utf8_str()));
+
+    ok = rAP.getProperty("right-space", pValue);
+    if(!ok)
+      m_rightSpace.clear();
+    else
+    {
+      m_rightSpace = pValue;
+    }
+
+    ok = rAP.getProperty("top-space", pValue);
+    if(!ok)
+      m_topSpace.clear();
+    else
+    {
+      m_topSpace = pValue;
+    }
+
     ok = rAP.getProperty("default-tab-interval", pValue);
     if (ok && pValue != NULL) {
         m_defaultTabInterval = pValue;
@@ -1216,6 +1516,16 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     ODe_writeAttribute(rOutput, "fo:keep-with-next", m_keepWithNext);
     ODe_writeAttribute(rOutput, "fo:break-before", m_breakBefore);
     ODe_writeAttribute(rOutput, "style:writing-mode", m_writingMode);
+    ODe_writeAttribute(rOutput, "fo:border-left", m_borderLeft);
+    ODe_writeAttribute(rOutput, "fo:border-right", m_borderRight);
+    ODe_writeAttribute(rOutput, "fo:border-top", m_borderTop);
+    ODe_writeAttribute(rOutput, "fo:border-bottom", m_borderBottom);
+    ODe_writeAttribute(rOutput, "fo:padding-bottom", m_botSpace);
+    ODe_writeAttribute(rOutput, "fo:padding-left", m_leftSpace);
+    UT_DEBUGMSG(("2 -m_leftspace %s \n",m_leftSpace.utf8_str()));
+    ODe_writeAttribute(rOutput, "fo:padding-right", m_rightSpace);
+    ODe_writeAttribute(rOutput, "fo:padding-top", m_topSpace);
+    ODe_writeAttribute(rOutput, "style:join-border", m_borderMerge);
 
     if (m_defaultStyle) {
         ODe_writeAttribute(rOutput, "style:tab-stop-distance", m_defaultTabInterval); 
@@ -1267,9 +1577,17 @@ ODe_Style_Style::ParagraphProps& ODe_Style_Style::ParagraphProps::operator=(
     m_keepWithNext = rParagraphProps.m_keepWithNext;
     m_breakBefore = rParagraphProps.m_breakBefore;
     m_writingMode = rParagraphProps.m_writingMode;
+    m_borderMerge = rParagraphProps.m_borderMerge;
+    m_borderLeft = rParagraphProps.m_borderLeft;
+    m_borderRight = rParagraphProps.m_borderRight;
+    m_borderTop = rParagraphProps.m_borderTop;
+    m_borderBottom = rParagraphProps.m_borderBottom;
+    m_botSpace = rParagraphProps.m_botSpace;
+    m_leftSpace = rParagraphProps.m_leftSpace;
+    m_rightSpace = rParagraphProps.m_rightSpace;
+    m_topSpace = rParagraphProps.m_topSpace;
     m_defaultTabInterval = rParagraphProps.m_defaultTabInterval;
     m_tabStops = rParagraphProps.m_tabStops;
-    
     return *this;
 }
 
@@ -1295,6 +1613,15 @@ bool ODe_Style_Style::ParagraphProps::operator==(
         m_keepWithNext    == rParagraphProps.m_keepWithNext &&
         m_breakBefore     == rParagraphProps.m_breakBefore &&
         m_writingMode     == rParagraphProps.m_writingMode &&
+        m_borderMerge     == rParagraphProps.m_borderMerge &&
+        m_borderLeft      == rParagraphProps.m_borderLeft &&
+        m_borderRight     == rParagraphProps.m_borderRight &&
+        m_borderTop       == rParagraphProps.m_borderTop &&
+        m_borderBottom    == rParagraphProps.m_borderBottom &&
+        m_botSpace        == rParagraphProps.m_botSpace &&
+        m_leftSpace       == rParagraphProps.m_leftSpace &&
+        m_rightSpace      == rParagraphProps.m_rightSpace &&
+        m_topSpace        == rParagraphProps.m_topSpace &&
         m_defaultTabInterval == rParagraphProps.m_defaultTabInterval &&
         m_tabStops        == rParagraphProps.m_tabStops;
 }
@@ -1433,17 +1760,6 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
         }
     }
 
-
-    ok = rAP.getProperty("bgcolor", pValue);
-    if (ok && pValue && *pValue) {
-        if (!strcmp("transparent", pValue)) {
-            m_backgroundColor = pValue;
-        } else {
-            m_backgroundColor = UT_colorToHex(pValue, true);
-        }
-    }
-
-
     ok = rAP.getProperty("display", pValue);
     if (ok && pValue != NULL) {
         if (!strcmp(pValue, "none")) {
@@ -1800,7 +2116,8 @@ bool ODe_Style_Style::CellProps::isEmpty() const {
            m_topColor.empty() &&
            m_bottomThickness.empty() &&
            m_bottomColor.empty() &&
-           m_backgroundColor.empty();
+           m_backgroundColor.empty() &&
+	   m_verticalAlign.empty();
 }
 
 
@@ -1905,6 +2222,19 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
         m_backgroundImage += pValue;
     }
 
+    // Vertical alignment
+    ok = rAP.getProperty("vert-align", pValue);
+    if (ok && pValue != NULL){
+	if(atoi(pValue) < 33)
+		m_verticalAlign = "top";
+	else if(atoi(pValue) < 66)
+		m_verticalAlign = "middle";
+	else
+		m_verticalAlign = "bottom";
+    } else if (m_verticalAlign.empty()) {
+	m_verticalAlign = "top";
+    }
+
 }
 
 
@@ -1924,11 +2254,13 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     else
       rOutput += "<style:table-cell-properties>";
 
+    ODe_writeAttribute(rOutput, "style:vertical-align", m_verticalAlign);
     ODe_writeAttribute(rOutput, "fo:border-left", m_leftThickness + " solid " + m_leftColor);
     ODe_writeAttribute(rOutput, "fo:border-right",m_rightThickness + " solid " + m_rightColor);
     ODe_writeAttribute(rOutput, "fo:border-top", m_topThickness + " solid " + m_topColor);
     ODe_writeAttribute(rOutput, "fo:border-bottom", m_bottomThickness + " solid " + m_bottomColor);
     ODe_writeAttribute(rOutput, "fo:background-color", m_backgroundColor);
+
     
     rOutput += "/>\n";
 
@@ -1961,6 +2293,7 @@ ODe_Style_Style::CellProps& ODe_Style_Style::CellProps::operator=(
     m_bottomThickness = rCellProps.m_bottomThickness;
     m_bottomColor = rCellProps.m_bottomColor;
     m_backgroundColor = rCellProps.m_backgroundColor;
+    m_verticalAlign = rCellProps.m_verticalAlign;
     
     return *this;
 }
@@ -1980,7 +2313,8 @@ bool ODe_Style_Style::CellProps::operator==(
         m_topColor           == rCellProps.m_topColor &&
         m_bottomThickness    == rCellProps.m_bottomThickness &&
         m_bottomColor        == rCellProps.m_bottomColor &&
-        m_backgroundColor    == rCellProps.m_backgroundColor;
+        m_backgroundColor    == rCellProps.m_backgroundColor &&
+	m_verticalAlign      == rCellProps.m_verticalAlign;
 }
 
 
