@@ -41,6 +41,7 @@
 #include <gsf/gsf-output-memory.h>
 #include <ut_units.h>
 #include <fl_TOCLayout.h>
+#include <pd_DocumentRDF.h>
 
 // External includes
 #include <stdlib.h>
@@ -64,6 +65,7 @@ ODe_Text_Listener::ODe_Text_Listener(ODe_Styles& rStyles,
                         m_isFirstCharOnParagraph(true),
                         m_openedODTextboxFrame(false),
                         m_openedODNote(false),
+                        m_bIgoreFirstTab(false),
                         m_pParagraphContent(NULL),
                         m_currentListLevel(0),
                         m_pCurrentListStyle(NULL),
@@ -99,6 +101,7 @@ ODe_Text_Listener::ODe_Text_Listener(ODe_Styles& rStyles,
                         m_isFirstCharOnParagraph(true),
                         m_openedODTextboxFrame(false),
                         m_openedODNote(false),
+			m_bIgoreFirstTab(false),
                         m_pParagraphContent(NULL),
                         m_currentListLevel(0),
                         m_pCurrentListStyle(NULL),
@@ -212,7 +215,7 @@ void ODe_Text_Listener::openSpan(const PP_AttrProp* pAP) {
         UT_UTF8String output;
         
         UT_UTF8String_sprintf(output, "<text:span text:style-name=\"%s\">",
-                              styleName.escapeXML().utf8_str());
+                              ODe_Style_Style::convertStyleToNCName(styleName).escapeXML().utf8_str());
                               
         ODe_writeUTF8String(m_pParagraphContent, output);
         m_openedODSpan = true;
@@ -502,10 +505,14 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
     str.clear();
     _printSpacesOffset(str);
     
+    UT_UTF8String tocName;
+    UT_UTF8String_sprintf(tocName, "Table of Contents %u", m_iCurrentTOC);
+    tocName.escapeXML();
+    
     UT_UTF8String_sprintf(output,
         "%s<text:table-of-content text:protected=\"true\""
-        " text:name=\"Table of Contents%u\">\n",
-        str.utf8_str(), m_iCurrentTOC);
+        " text:name=\"%s\">\n",
+        str.utf8_str(), tocName.utf8_str());
    
     ODe_writeUTF8String(m_pTextOutput, output);
     m_spacesOffset++;
@@ -557,7 +564,7 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
     if (hasHeading) {
         _printSpacesOffset(output);
         output += "<text:index-title-template text:style-name=\"";
-        output += headingStyle.escapeXML();     
+        output += ODe_Style_Style::convertStyleToNCName(headingStyle).escapeXML();     
         output += "\">";
         output += tocHeading.escapeXML();        
         output += "</text:index-title-template>\n";
@@ -582,7 +589,7 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
 
         UT_UTF8String destStyle = m_rAuxiliaryData.m_mDestStyles[outlineLevel];
         UT_ASSERT_HARMLESS(destStyle != "");
-        output += destStyle.escapeXML();
+        output += ODe_Style_Style::convertStyleToNCName(destStyle).escapeXML();
         
         output += "\">\n";
         m_spacesOffset++;
@@ -630,12 +637,15 @@ void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
         m_spacesOffset++;
 
         if (hasHeading) {
-            output += "<text:index-title>\n";
+            _printSpacesOffset(output);
+            output += "<text:index-title text:name=\"";
+            output += tocName; // the text:name field is required and should be unique
+            output += "\">\n";
 
             m_spacesOffset++;
             _printSpacesOffset(output);
             output += "<text:p text:style-name=\"";
-            output += headingStyle.escapeXML();
+            output += ODe_Style_Style::convertStyleToNCName(headingStyle).escapeXML();
             output += "\">";
             output += tocHeading.escapeXML();
             output += "</text:p>\n"; 
@@ -690,7 +700,15 @@ void ODe_Text_Listener::openBookmark(const PP_AttrProp* pAP) {
 
             if(escape.length()) {
                 output+= escape;
-                output+="\"/>";
+                output+="\" ";
+
+                const char* xmlid = 0;
+                if( pAP->getAttribute( PT_XMLID, xmlid ) && xmlid )
+                {
+                    appendAttribute( output, "xml:id", xmlid );
+                }
+
+                output+=" />";
                 ODe_writeUTF8String(m_pParagraphContent, output);
             }
         }
@@ -769,6 +787,30 @@ void ODe_Text_Listener::closeHyperlink() {
     ODe_writeUTF8String(m_pParagraphContent, output);
 }
 
+void ODe_Text_Listener::openRDFAnchor(const PP_AttrProp* pAP)
+{
+    UT_return_if_fail(pAP);
+    RDFAnchor a(pAP);
+    
+    UT_UTF8String output = "<text:meta ";
+    UT_UTF8String escape = a.getID().c_str();
+    escape.escapeURL();
+    
+    output+=" xml:id=\"";
+    output+= escape;
+    output+="\" ";
+    output+=" >";
+    ODe_writeUTF8String(m_pParagraphContent, output);
+}
+
+
+void ODe_Text_Listener::closeRDFAnchor(const PP_AttrProp* pAP)
+{
+    RDFAnchor a(pAP);
+    UT_UTF8String output = "</text:meta>";
+    ODe_writeUTF8String(m_pParagraphContent, output);
+}
+
 /**
  * 
  */
@@ -832,11 +874,15 @@ void ODe_Text_Listener::insertPageBreak() {
 void ODe_Text_Listener::insertTabChar() {
     // We will not write the tab char that abi inserts right after each
     // list item bullet/number.
-    if (!m_isFirstCharOnParagraph || m_currentListLevel == 0) {
-        ODe_writeUTF8String(m_pParagraphContent, "<text:tab/>");
+  // Also don't write out the tab after a note anchor
+    
+  if (!m_bIgoreFirstTab && (!m_isFirstCharOnParagraph || (m_currentListLevel == 0)))
+    {
+      ODe_writeUTF8String(m_pParagraphContent, "<text:tab/>");
     }
 
     m_isFirstCharOnParagraph = false;
+    m_bIgoreFirstTab = false;
 }
 
 
@@ -1032,23 +1078,23 @@ void ODe_Text_Listener::insertPositionedImage(const gchar* pImageName,
     }
     else if(ok && pValue && !strcmp(pValue, "page-above-text")) {
         output+="page\"";
-	ok = pAP->getProperty("frame-page-xpos", pValue);
-	UT_ASSERT(ok && pValue != NULL);
-        ODe_writeAttribute(output, "svg:x", pValue);
+        ok = pAP->getProperty("frame-page-xpos", pValue);
+        if (ok && pValue != NULL)
+            ODe_writeAttribute(output, "svg:x", pValue);
         
-	ok = pAP->getProperty("frame-page-ypos", pValue);
-	UT_ASSERT(ok && pValue != NULL);
-        ODe_writeAttribute(output, "svg:y", pValue);
+        ok = pAP->getProperty("frame-page-ypos", pValue);
+        if (ok && pValue != NULL)
+            ODe_writeAttribute(output, "svg:y", pValue);
     }
     else { //this handles the block-above-text case and any other unforeseen ones
         output+="paragraph\"";
-	ok = pAP->getProperty("xpos", pValue);
-	UT_ASSERT(ok && pValue != NULL);
-        ODe_writeAttribute(output, "svg:x", pValue);
+        ok = pAP->getProperty("xpos", pValue);
+        if (ok && pValue != NULL)
+            ODe_writeAttribute(output, "svg:x", pValue);
         
-	ok = pAP->getProperty("ypos", pValue);
-	UT_ASSERT(ok && pValue != NULL);
-        ODe_writeAttribute(output, "svg:y", pValue);
+        ok = pAP->getProperty("ypos", pValue);
+        if (ok && pValue != NULL)
+            ODe_writeAttribute(output, "svg:y", pValue);
     }
 
     UT_UTF8String_sprintf(str, "%u", m_zIndex);
@@ -1173,7 +1219,7 @@ void ODe_Text_Listener::_openODListItem(const PP_AttrProp* pAP) {
             m_pCurrentListStyle = m_rAutomatiStyles.addListStyle();
             
             output += "<text:list text:style-name=\"";
-            output += m_pCurrentListStyle->getName();
+            output += ODe_Style_Style::convertStyleToNCName(m_pCurrentListStyle->getName()).escapeXML();
             output += "\">\n";
             
         } else {
@@ -1355,10 +1401,17 @@ void ODe_Text_Listener::_openODParagraph(const PP_AttrProp* pAP) {
             
             escape = styleName;
             output += "<text:h text:style-name=\"";
-            output += escape.escapeXML();
+            output += ODe_Style_Style::convertStyleToNCName(escape).escapeXML();
             output += "\" text:outline-level=\"";
             output += str;
-            output += "\">";
+            output += "\" ";
+            const char* xmlid = 0;
+            if( pAP->getAttribute( PT_XMLID, xmlid ) && xmlid )
+            {
+                appendAttribute( output, "xml:id", xmlid );
+            }
+
+            output += " >";
             
             m_isHeadingParagraph = true;
             
@@ -1366,8 +1419,14 @@ void ODe_Text_Listener::_openODParagraph(const PP_AttrProp* pAP) {
             // It's a regular paragraph.
             escape = styleName;
             output += "<text:p text:style-name=\"";
-            output += escape.escapeXML();
-            output += "\">";
+            output += ODe_Style_Style::convertStyleToNCName(escape).escapeXML();
+            output += "\" ";
+            const char* xmlid = 0;
+            if( pAP->getAttribute( PT_XMLID, xmlid ) && xmlid )
+            {
+                appendAttribute( output, "xml:id", xmlid );
+            }
+            output += ">";
             
             m_isHeadingParagraph = false;
         }
@@ -1437,3 +1496,18 @@ void ODe_Text_Listener::_closeODParagraph() {
         m_spacesOffset--;
     }
 }
+
+UT_UTF8String& ODe_Text_Listener::appendAttribute(
+    UT_UTF8String& ret,
+    const char* key,
+    const char* value )
+{
+    UT_UTF8String escape = value;
+    ret += " ";
+    ret += key;
+    ret += "=\"";
+    ret += escape.escapeXML();
+    ret += "\" ";
+    return ret;
+}
+
