@@ -48,11 +48,17 @@
 
 #include <boost/shared_array.hpp>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 // RDF support
+#ifdef WITH_REDLAND
+#include "pd_RDFSupportRed.h"
 #include <redland.h>
 #include <rasqal.h>
 #define DEBUG_RDF_IO 1
-
+#endif
 
 /**
  * Constructor
@@ -83,7 +89,7 @@ IE_Imp_OpenDocument::~IE_Imp_OpenDocument ()
 bool IE_Imp_OpenDocument::pasteFromBuffer(PD_DocumentRange * pDocRange,
 				    const unsigned char * pData, 
 				    UT_uint32 lenData, 
-				    const char * szEncoding)
+					  const char * /*szEncoding*/)
 {
     UT_return_val_if_fail(getDoc() == pDocRange->m_pDoc,false);
     UT_return_val_if_fail(pDocRange->m_pos1 == pDocRange->m_pos2,false);
@@ -101,6 +107,16 @@ bool IE_Imp_OpenDocument::pasteFromBuffer(PD_DocumentRange * pDocRange,
     pODImp->loadFile(newDoc, pInStream);
     // pInStream deleted after load.
     newDoc->finishRawCreation();
+
+    // Handle RDF for the newdoc
+    {
+        PD_DocumentRDFHandle rdf = newDoc->getDocumentRDF();
+        rdf->dumpModel("about to broadcast...");
+        PD_DocumentRDFMutationHandle m = getDoc()->getDocumentRDF()->createMutation();
+        m->add( rdf );
+        m->commit();
+    }
+    
     //
     // OK Broadcast from the just filled source document into our current
     // doc via the paste listener
@@ -381,82 +397,6 @@ UT_Error IE_Imp_OpenDocument::_handleContentStream ()
     return _handleStream (m_pGsfInfile, "content.xml", *m_pStreamListener);
 }
 
-/**
- * A class purely to pass redland objects like world, parsers and
- * models and other redland stuff to other methods without exposing
- * their types in the header file.
- *
- * Instead of passing in these things to
- * the constructor, I moved to a design where the objects are owned
- * by this class, so if you declaure a RDFArguments on the stack, RAII
- * will deallocate the world, parser, and model for you. Less to possibly leak.
- */
-class RDFArguments
-{
-public:
-    librdf_world*   world;
-    librdf_storage* storage;
-    librdf_model*   model;
-    librdf_parser*  parser;
-    
-    RDFArguments()
-        :
-        world(0), storage(0), model(0), parser(0)
-    {
-        world = librdf_new_world();
-        librdf_world_open( world );
-        storage = librdf_new_storage( world, "memory", "/", 0 );    
-        model   = librdf_new_model(   world, storage, 0 );
-        parser  = librdf_new_parser(  world, 0, 0, 0 );
-    }
-
-    ~RDFArguments()
-    {
-        librdf_free_parser( parser );
-        librdf_free_model( model );
-        librdf_free_storage( storage );
-        librdf_free_world( world );
-    }
-private:
-    // NoCopying!
-    RDFArguments&  operator=(const RDFArguments& other);
-    RDFArguments(const RDFArguments& other);
-};
-
-static std::string toString( librdf_uri *node )
-{
-    unsigned char* z = librdf_uri_as_string( node );
-    std::string ret = (const char*)z;
-    // For this redland as_string() function, we do not free z.
-    return ret;
-}
-
-
-static std::string toString( librdf_node *node )
-{
-    unsigned char* z = 0;
-    std::string s;
-    librdf_node_type t = librdf_node_get_type( node );
-    switch( t )
-    {
-        case LIBRDF_NODE_TYPE_BLANK:
-            z = librdf_node_get_blank_identifier( node );
-            s = (const char*)z;
-            return s;
-        case  LIBRDF_NODE_TYPE_LITERAL:
-            z = librdf_node_get_literal_value( node );
-            s = (const char*)z;
-            return s;
-        case LIBRDF_NODE_TYPE_RESOURCE:
-            return toString( librdf_node_get_uri(node) );
-    }
-
-    // fallback
-    z = librdf_node_to_string( node );
-    std::string ret = (const char*)z;
-    free(z);
-    return ret;
-}
 
 
 UT_Error IE_Imp_OpenDocument::_loadRDFFromFile ( GsfInput* pInput,
@@ -464,7 +404,10 @@ UT_Error IE_Imp_OpenDocument::_loadRDFFromFile ( GsfInput* pInput,
                                                  RDFArguments* args )
 {
     UT_return_val_if_fail(pInput, UT_ERROR);
-
+#ifndef WITH_REDLAND
+    return(UT_OK);
+#else
+    
     int sz = gsf_input_size (pInput);
     if (sz > 0)
     {
@@ -505,15 +448,32 @@ UT_Error IE_Imp_OpenDocument::_loadRDFFromFile ( GsfInput* pInput,
     }
 
     return UT_OK;
+#endif
 }
 
                       
 UT_Error IE_Imp_OpenDocument::_handleRDFStreams ()
 {
+#ifndef WITH_REDLAND
+    return UT_OK;
+#else
     UT_Error error = UT_OK;
-
+    
     UT_DEBUGMSG(("IE_Imp_OpenDocument::_handleRDFStreams()\n"));
 
+    // // DEBUG.
+    // {
+    //     PD_DocumentRDFHandle rdf = getDoc()->getDocumentRDF();
+    //     PD_DocumentRDFMutationHandle m = rdf->createMutation();
+    //     m->add( PD_URI("http://www.example.com/foo#bar" ),
+    //             PD_URI("http://www.example.com/foo#bar" ),
+    //             PD_Object("http://www.example.com/foo#bar" ) );
+    //     m->commit();
+    //     rdf->dumpModel("added foo");
+    // }
+    
+
+    
     RDFArguments args;
     librdf_model* model = args.model;
 
@@ -521,6 +481,7 @@ UT_Error IE_Imp_OpenDocument::_handleRDFStreams ()
     GsfInput* pRdfManifest = gsf_infile_child_by_name(m_pGsfInfile, "manifest.rdf");
     if (pRdfManifest)
     {
+        UT_DEBUGMSG(("IE_Imp_OpenDocument::_handleRDFStreams() have manifest.rdf\n"));
         error = _loadRDFFromFile( pRdfManifest, "manifest.rdf", &args );
         g_object_unref (G_OBJECT (pRdfManifest));
         if (error != UT_OK)
@@ -593,7 +554,6 @@ UT_Error IE_Imp_OpenDocument::_handleRDFStreams ()
     {
         PD_DocumentRDFHandle rdf = getDoc()->getDocumentRDF();
         PD_DocumentRDFMutationHandle m = rdf->createMutation();
-
         librdf_statement* statement = librdf_new_statement( args.world );
         librdf_stream* stream = librdf_model_find_statements( model, statement );
 
@@ -630,18 +590,25 @@ UT_Error IE_Imp_OpenDocument::_handleRDFStreams ()
                                 ));
             }
             
-            
             m->add( PD_URI( toString( librdf_statement_get_subject( current ))),
                     PD_URI( toString( librdf_statement_get_predicate( current ))),
-                    PD_Object( toString( librdf_statement_get_object( current )),
-                               objectType,
-                               xsdType ));
+                    PD_Object( toString( librdf_statement_get_object( current )), objectType, xsdType ));
+
+            // m->add( PD_URI( toString( librdf_statement_get_subject( current ))),
+            //         PD_URI( toString( librdf_statement_get_predicate( current ))),
+            //         PD_Object( toString( librdf_statement_get_object( current )),
+            //                    objectType,
+            //                    xsdType ));
 
             librdf_stream_next(stream);
         }
         
         librdf_free_stream( stream );
         librdf_free_statement( statement );
+        // m->add( PD_URI("http://www.example.com/foo#bar" ),
+        //         PD_URI("http://www.example.com/foo#bar" ),
+        //         PD_Object("http://www.example.com/foo#bar" ) );
+        m->commit();
     }
 
     if( DEBUG_RDF_IO )
@@ -649,6 +616,7 @@ UT_Error IE_Imp_OpenDocument::_handleRDFStreams ()
         getDoc()->getDocumentRDF()->dumpModel("Loaded RDF from ODF file");
     }
     return error;
+#endif
 }
 
 
@@ -669,7 +637,13 @@ UT_Error IE_Imp_OpenDocument::_handleStream ( GsfInfile* pGsfInfile,
     if (pos != m_cryptoInfo.end())
 	{
         UT_DEBUGMSG(("Running decrypt on stream %s\n", pStream));
-		
+
+        
+#ifndef HAVE_GCRYPT
+        UT_DEBUGMSG(("Can not decrypt files because of how abiword is compiled!\n"));
+        return UT_ERROR;
+#endif
+        
         GsfInput* pDecryptedInput = NULL;
         UT_Error err = ODc_Crypto::decrypt(pInput, (*pos).second, m_sPassword.utf8_str(), &pDecryptedInput);
         g_object_unref (G_OBJECT (pInput));
