@@ -32,7 +32,7 @@
 /* GTK build supports platforms without PATH_MAX; we leave the warning in for
  * other platforms to avoid headaches
  */
-#if !defined(PATH_MAX) && !defined(TOOLKIT_GTK)
+#if !defined(PATH_MAX) && !defined(TOOLKIT_GTK_ALL)
 #error Huh, neither MAXPATHLEN nor PATH_MAX available, fix for this platform needed.
 #endif
 
