@@ -242,6 +242,9 @@ public:
 	 * 	xmlstr.replace ("&lt;", "<");
 	 * 	xmlstr.replace ("&gt;", ">");
 	 * 	xmlstr.replace ("&amp;","&");
+	 *
+	 * 	MIQ: Note that for these replace methods, one might use ut_std_string/replace_all()
+	 *
 	 * 
 	 * getIterator:
 	 * returns a home-made iterator associated with the UTF-8 string, e.g.:
@@ -347,6 +350,8 @@ public:
 	void        clear() const;
 
 	UT_UCS4String	substr(size_t iStart, size_t nChars) const;
+	UT_UCS4String	substr(size_t iStart) const;
+	UT_UCS4String	substr( const UT_UCS4Char* iter ) const;
 
 	UT_UCS4String&	operator=(const UT_UCS4String&  rhs);
 	UT_UCS4String&	operator=(const UT_UCS4Char *   rhs);
@@ -366,6 +371,10 @@ public:
 	// even if to an empty (0) string.
 	const UT_UCS4Char* ucs4_str() const;
 
+    // The same valid constraints as ucs4_str() applies to begin and end
+    const UT_UCS4Char* begin() const;
+    const UT_UCS4Char* end()   const;
+    
 	const char * utf8_str ();
 
 private:
