@@ -60,6 +60,14 @@ typedef gint32		    UT_sint32;
 typedef guint64 UT_uint64;
 typedef gint64 UT_sint64;
 
+#ifdef _WIN64
+typedef guint64 	UT_uintptr;
+typedef gint64 	UT_sintptr;
+#else
+typedef unsigned long UT_uintptr;
+typedef long        UT_sintptr;
+#endif
+
 /** use to mark variable as unused */
 #define UT_UNUSED(x) (void)(x);
 
@@ -85,8 +93,10 @@ typedef UT_uint8 UT_Confidence_t;
      #define ABI_EXPORT __declspec(dllexport)
   #endif
 #elif defined (DISABLE_EXPORTS)
+  /* ignore DISABLE_EXPORTS until we have assigned all symbols proper
+   * visibility */
   #define ABI_PLUGIN_EXPORT
-  #define ABI_EXPORT __attribute__ ((visibility ("hidden")))
+  #define ABI_EXPORT
 #else
   #define ABI_PLUGIN_EXPORT
   #define ABI_EXPORT
