@@ -228,11 +228,12 @@ void connectFocusModeless(GtkWidget *widget,const XAP_App * pApp)
 
 bool isTransientWindow(GtkWindow *window,GtkWindow *parent)
 {
+  GtkWindow *transient;
   if(window)
 	{
-	  while(window->transient_parent)
+	  while((transient=gtk_window_get_transient_for(window)))
 		{
-		  window=window->transient_parent;
+		  window=transient;
 		  if(window==parent)
 			return true;
 		}
@@ -271,7 +272,7 @@ static gint modal_keypress_cb ( GtkWidget * /*wid*/, GdkEventKey * event,
 								XAP_Dialog * pDlg )
 {
 	// propegate keypress up if not F1
-	if ( event->keyval == GDK_F1 || event->keyval == GDK_Help )
+	if ( event->keyval == GDK_KEY_F1 || event->keyval == GDK_KEY_Help )
 	{
 		sDoHelp( pDlg ) ;
 
@@ -289,7 +290,7 @@ static gint nonmodal_keypress_cb ( GtkWidget * /*wid*/, GdkEventKey * event,
 								   XAP_Dialog * pDlg )
 {
 	// propegate keypress up if not F1
-	if ( event->keyval == GDK_F1 || event->keyval == GDK_Help )
+	if ( event->keyval == GDK_KEY_F1 || event->keyval == GDK_KEY_Help )
 	{
 		sDoHelp( pDlg ) ;
 		return TRUE ;
@@ -330,9 +331,9 @@ static void sAddHelpButton (GtkDialog * me, XAP_Dialog * pDlg)
 	GtkWidget * alignment = gtk_button_new_from_stock (GTK_STOCK_HELP);
 	GtkWidget * button = alignment;
 #endif
-    gtk_box_pack_start(GTK_BOX(me->action_area),
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_action_area(me)),
 		       alignment, FALSE, FALSE, 0);
-    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX(me->action_area),
+    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX(gtk_dialog_get_action_area(me)),
 					alignment, TRUE);
     g_signal_connect (G_OBJECT (button), "clicked",
 		      G_CALLBACK(help_button_cb), pDlg);
@@ -425,7 +426,12 @@ gint abiRunModalDialog(GtkDialog * me, XAP_Frame *pFrame, XAP_Dialog * pDlg,
 					   gint defaultResponse, bool destroyDialog, AtkRole role)
 {
   abiSetupModalDialog(me, pFrame, pDlg, defaultResponse);
-  return abiRunModalDialog(me, destroyDialog, role);
+  gint ret = abiRunModalDialog(me, destroyDialog, role);
+  if( pDlg )
+  {
+      pDlg->maybeReallowPopupPreviewBubbles();
+  }
+  return ret;
 }
 
 /*!
@@ -470,7 +476,9 @@ void abiSetupModelessDialog(GtkDialog * me, XAP_Frame * pFrame, XAP_Dialog * pDl
 	gtk_window_set_modal ( GTK_WINDOW(me), FALSE ) ;
 	// FIXME: shouldn't we pass role here?
 	atk_object_set_role (gtk_widget_get_accessible (GTK_WIDGET (me)), ATK_ROLE_ALERT);
-	
+
+    pDlg->maybeClosePopupPreviewBubbles();
+        
 	// show the window
 	gtk_widget_show ( GTK_WIDGET(me) ) ;
 }
@@ -484,9 +492,8 @@ GtkWidget * abiDialogNew(const char * role, gboolean resizable)
   if ( role )
     gtk_window_set_role ( GTK_WINDOW(dlg), role ) ;
   gtk_window_set_resizable ( GTK_WINDOW(dlg), resizable ) ;
-  gtk_dialog_set_has_separator ( GTK_DIALOG (dlg), false ) ;
   gtk_container_set_border_width ( GTK_CONTAINER (dlg), 5 ) ;
-  gtk_box_set_spacing ( GTK_BOX ( GTK_DIALOG (dlg)->vbox), 2 ) ;
+  gtk_box_set_spacing ( GTK_BOX ( gtk_dialog_get_content_area(GTK_DIALOG (dlg))), 2 ) ;
   return dlg ;
 }
 
@@ -762,40 +769,6 @@ void setLabelMarkup(GtkWidget * widget, const gchar * str)
 	gtk_label_set_markup (GTK_LABEL(widget), markupStr.c_str());
 }
 
-
-/*!
- * For a parented/displayed widget, this will just return
- * gtk_widget_ensure_style(w). For a non-displayed widgets,
- * This will return a valid GtkStyle for that widget
- */
-GtkStyle *
-get_ensured_style (GtkWidget * w)
-{
-	GtkStyle  * style = NULL;
-	GtkWidget * hidden_window = NULL;
-
-	if (w->parent == NULL)
-	{
-		hidden_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-		gtk_container_add (GTK_CONTAINER (hidden_window), w);
-	}
-
-	gtk_widget_ensure_style (w);
-	gtk_widget_realize (w);
-
-	style = gtk_widget_get_style (w);
-	UT_ASSERT(style);
-
-	if (hidden_window)
-	{
-		// now we destroy the hidden window
-		gtk_container_remove (GTK_CONTAINER(hidden_window), w);
-		gtk_widget_destroy (hidden_window);
-	}
-
-	return style;
-}
-
 /*!
  * Creates a new GdkDrawingArea with the proper colormap and visual
  * This returns a single-buffered widget.
@@ -842,3 +815,24 @@ GdkWindow * getRootWindow(GtkWidget * widget)
 	UT_return_val_if_fail(widget, NULL);
 	return gdk_get_default_root_window() ;
 }
+
+
+static void activate_button( GtkEntry * /*entry*/, gpointer user_data )
+{
+//    UT_DEBUGMSG(("activate_button() ud:%x\n", user_data ));
+
+    GtkWidget* w = GTK_WIDGET(user_data);
+    gtk_widget_activate(w);
+}
+
+/**
+ * When the source widget gets the activate signal, sent activate to the button.
+ * This allows GtkEntry widgets to explicitly close the dialog with the OK button
+ * when the user presses return while leaving the default dialog action to be CANCEL.
+ */
+void abiSetActivateOnWidgetToActivateButton( GtkWidget* source, GtkWidget* button )
+{
+    g_signal_connect( G_OBJECT( source ), "activate",
+                      G_CALLBACK(activate_button), button );
+}
+
