@@ -61,7 +61,7 @@ void XAP_UnixDialog_About::runModal(XAP_Frame * pFrame)
 	static const gchar *documenters[] = {"David Chart <linux@dchart.demon.co.uk>",
 										 NULL};
 
-	static const gchar *copyright = "(c) 1998-2010 Dom Lachowicz and other contributors, GNU GPL v2.0";
+	static const gchar *copyright = "(c) 1998-2011 Dom Lachowicz and other contributors, GNU GPL v2.0";
 
 	static const gchar *website = "http://www.abisource.com";
 
@@ -83,7 +83,8 @@ void XAP_UnixDialog_About::runModal(XAP_Frame * pFrame)
 	parent = gtk_widget_get_parent(pUnixFrameImpl->getTopLevelWindow());
 
 	dlg = gtk_about_dialog_new();
-	gtk_about_dialog_set_url_hook(onAboutDialogActivate, NULL, NULL);
+	//JEAN: do we really need the "activate-link" signal?
+	g_signal_connect(dlg, "activate-link", G_CALLBACK(onAboutDialogActivate), NULL);
 	gtk_show_about_dialog(GTK_WINDOW (parent), 
 						  "authors", authors, 
 						  "documenters", documenters, 
