@@ -142,8 +142,8 @@ static void s_delete_clicked(GtkWidget 	* /*widget*/,
 	gtk_main_quit();
 }
 
-static gint s_preview_exposed(GtkWidget * /* widget */,
-			      GdkEventExpose * /* pExposeEvent */,
+static gint s_preview_draw(GtkWidget * /* widget */,
+			      cairo_t * /* cr */,
 			      gpointer ptr)
 {
         XAP_UnixDialog_FileOpenSaveAs * dlg = static_cast<XAP_UnixDialog_FileOpenSaveAs *> (ptr);
@@ -161,7 +161,7 @@ static void s_filetypechanged(GtkWidget * w, gpointer p)
 static gint
 fsel_key_event (GtkWidget * widget, GdkEventKey * event, XAP_Dialog_FileOpenSaveAs::tAnswer * answer)
 {
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		g_signal_stop_emission_by_name (G_OBJECT (widget), "key_press_event");
 		s_dialog_response(widget, GTK_RESPONSE_CANCEL, answer);
 		return TRUE;
@@ -181,7 +181,7 @@ static void s_file_activated(GtkWidget * w, XAP_Dialog_FileOpenSaveAs::tAnswer *
 }
 
 static void file_selection_changed  (GtkTreeSelection  * /*selection*/,
-				     gpointer           ptr)
+                                    gpointer           ptr)
 {
   XAP_UnixDialog_FileOpenSaveAs * dlg = static_cast<XAP_UnixDialog_FileOpenSaveAs *> (ptr);
 
@@ -296,18 +296,22 @@ bool XAP_UnixDialog_FileOpenSaveAs::_run_gtk_main(XAP_Frame * pFrame,
 						// if the file doesn't have a suffix already, and the file type
 						// is normal (special types are negative, like auto detect),
 						// and the user wants extensions, slap a suffix on it.						
-						// add suffix based on selected file type       
-						UT_UTF8String suffix (IE_Exp::preferredSuffixForFileType(m_nTypeList[nIndex]));
-						UT_uint32 length = strlen(szDialogFilename) + suffix.size() + 1;
+						// add suffix based on selected file type
+                        // UT_UTF8String suffix (IE_Exp::preferredSuffixForFileType(m_nTypeList[nIndex]));
+						// UT_uint32 length = strlen(szDialogFilename) + suffix.size() + 1;
 						
-						szFinalPathname = static_cast<char *>(UT_calloc(length,sizeof(char)));
+						// szFinalPathname = static_cast<char *>(UT_calloc(length,sizeof(char)));
 						
-						if (szFinalPathname)                            						
-						{                                               
-							char * p = szFinalPathname;             
-							strcpy(p,szDialogFilename);             
-							strcat(p,suffix.utf8_str());                     
-						}                                               
+						// if (szFinalPathname)                            						
+						// {                                               
+						// 	char * p = szFinalPathname;             
+						// 	strcpy(p,szDialogFilename);             
+						// 	strcat(p,suffix.utf8_str());                     
+						// }                                               
+
+                        std::string n = m_appendDefaultSuffixFunctor( szDialogFilename,
+                                                                      m_nTypeList[nIndex] );
+                        szFinalPathname = g_strdup( n.c_str() );
 					}
 					else
 						szFinalPathname = g_strdup(szDialogFilename);
@@ -472,7 +476,7 @@ void XAP_UnixDialog_FileOpenSaveAs::fileTypeChanged(GtkWidget * w)
 
 void XAP_UnixDialog_FileOpenSaveAs::onDeleteCancel() 
 {
-	if (m_FC != NULL && GTK_WIDGET_HAS_GRAB(GTK_WIDGET (m_FC))) {
+	if (m_FC != NULL && gtk_widget_has_grab(GTK_WIDGET (m_FC))) {
 		gtk_grab_remove (GTK_WIDGET (m_FC));
 	}
 	m_FC = NULL;
@@ -582,7 +586,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(pFrame->getFrameImpl());
 	GtkWidget * parent = pUnixFrameImpl->getTopLevelWindow();
 
-	if(parent && (GTK_WIDGET_TOPLEVEL(parent) != TRUE))
+	if(parent && (gtk_widget_is_toplevel(parent) != TRUE))
 	{
         parent = gtk_widget_get_toplevel (parent);
 	}
@@ -622,7 +626,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		gtk_widget_set_size_request (preview, PREVIEW_WIDTH, PREVIEW_HEIGHT);
 		
 		// place the preview area inside a container to get a nice border
-		GtkWidget * preview_hbox = gtk_hbox_new(FALSE, 0);
+		GtkWidget * preview_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_set_border_width  (GTK_CONTAINER(preview_hbox), 4);
 		gtk_box_pack_start(GTK_BOX(preview_hbox), preview, TRUE, TRUE, 0);
 		
@@ -634,8 +638,8 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		g_signal_connect (m_FC, "update_preview",
 								G_CALLBACK (file_selection_changed), static_cast<gpointer>(this));
 		
-		g_signal_connect (preview, "expose_event",
-								G_CALLBACK (s_preview_exposed), static_cast<gpointer>(this));
+		g_signal_connect (preview, "draw",
+								G_CALLBACK (s_preview_draw), static_cast<gpointer>(this));
 	}
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
@@ -644,7 +648,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	GtkWidget * pulldown_hbox = filetypes_pulldown;
 #else
 	// hbox for our pulldown menu (GTK does its pulldown this way */
-	GtkWidget * pulldown_hbox = gtk_hbox_new(FALSE, 15);
+	GtkWidget * pulldown_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 15);
 	gtk_widget_show(pulldown_hbox);
 
 	// pulldown label
@@ -700,7 +704,10 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	m_wFileTypes_PullDown = filetypes_pulldown;
 	// dialog; open dialog always does auto-detect
 	// TODO: should this also apply to the open dialog?
-	if (m_id == XAP_DIALOG_ID_FILE_SAVEAS || m_id == XAP_DIALOG_ID_FILE_SAVE_IMAGE)
+	if (m_id == XAP_DIALOG_ID_FILE_SAVEAS
+        || m_id == XAP_DIALOG_ID_FILE_SAVE_IMAGE
+        || ( m_id == XAP_DIALOG_ID_FILE_EXPORT && activeItemIndex >= 0 )
+        )
 	{
 		gtk_combo_box_set_active(combo, activeItemIndex + 1);
 	}
@@ -870,6 +877,14 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 	UT_return_val_if_fail( pSS, 0 );
+
+	/* do not try to scale an image to a 1x1 pibuf, this might happen when
+	   the widget size has notbeen allocated or if there is no room for it,
+	   that might freeze gdk_pixbuf */
+	GtkAllocation allocation;
+	gtk_widget_get_allocation (m_preview, &allocation);
+	if (allocation.width <= 1)
+		return 0;
 	
 	// attach and clear the area immediately
 	GR_UnixCairoAllocInfo ai(m_preview);
@@ -898,11 +913,13 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 
 	{
 	GR_Painter painter(pGr);
-	painter.clearArea(0, 0, pGr->tlu(m_preview->allocation.width), pGr->tlu(m_preview->allocation.height));
+	GtkAllocation alloc;
+	gtk_widget_get_allocation(m_preview, &alloc);
+	painter.clearArea(0, 0, pGr->tlu(alloc.width), pGr->tlu(alloc.height));
 
 	if (!file_name)
 	{
-		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(alloc.height / 2)) - pGr->getFontHeight(fnt)/2);
 	    goto Cleanup;
 	}
 
@@ -912,7 +929,7 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	{
 		if (!S_ISREG(st.st_mode)) 
 		{
-			painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+			painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(alloc.height / 2)) - pGr->getFontHeight(fnt)/2);
 			goto Cleanup;
 		}
 	}
@@ -930,7 +947,7 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	IEGraphicFileType ief = IE_ImpGraphic::fileTypeForContents(Buf,4096);
 	if((ief == IEGFT_Unknown) || (ief == IEGFT_Bogus))
 	{
-		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(alloc.height / 2)) - pGr->getFontHeight(fnt)/2);
 			g_object_unref (G_OBJECT (input));
 			goto Cleanup;
 	}
@@ -940,7 +957,7 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	UT_Byte * bytes = (UT_Byte *) gsf_input_read(input, num_bytes,NULL );
 	if(bytes == NULL)
 	{
-		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
+		    painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(alloc.height / 2)) - pGr->getFontHeight(fnt)/2);
 			g_object_unref (G_OBJECT (input));
 			goto Cleanup;
 	}
@@ -950,7 +967,8 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	//
 	// OK load the data into a GdkPixbuf
 	//
-	bool bLoadFailed = false;
+	// Jean: comented out next line (and an other one below), we don't use it
+	// bool bLoadFailed = false;
 	//
 	GdkPixbuf * pixbuf = pixbufForByteBuf ( pBB);
 	delete pBB;
@@ -959,8 +977,8 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 		//
 		// Try a fallback loader here.
 		//
-		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(m_preview->allocation.height / 2)) - pGr->getFontHeight(fnt)/2);
-		bLoadFailed = true;
+		painter.drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(static_cast<int>(alloc.height / 2)) - pGr->getFontHeight(fnt)/2);
+		// bLoadFailed = true;
 	    goto Cleanup;
 	}
 
@@ -968,19 +986,19 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 
 	iImageWidth = gdk_pixbuf_get_width (pixbuf);
 	iImageHeight = gdk_pixbuf_get_height (pixbuf);
-	if (m_preview->allocation.width >= iImageWidth && m_preview->allocation.height >= iImageHeight)
+	if (alloc.width >= iImageWidth && alloc.height >= iImageHeight)
 		scale_factor = 1.0;
 	else
-		scale_factor = MIN( static_cast<double>(m_preview->allocation.width)/iImageWidth,
-							static_cast<double>(m_preview->allocation.height)/iImageHeight);
+		scale_factor = MIN( static_cast<double>(alloc.width)/iImageWidth,
+							static_cast<double>(alloc.height)/iImageHeight);
 		
 	scaled_width  = static_cast<int>(scale_factor * iImageWidth);
 	scaled_height = static_cast<int>(scale_factor * iImageHeight);
 
 	static_cast<GR_UnixImage *>(pImage)->scale(scaled_width,scaled_height);	
 	painter.drawImage(pImage,
-					  pGr->tlu(static_cast<int>((m_preview->allocation.width  - scaled_width ) / 2)),
-					  pGr->tlu(static_cast<int>((m_preview->allocation.height - scaled_height) / 2)));
+					  pGr->tlu(static_cast<int>((alloc.width  - scaled_width ) / 2)),
+					  pGr->tlu(static_cast<int>((alloc.height - scaled_height) / 2)));
 		
 	answer = 1;
 	}
