@@ -23,8 +23,9 @@
 #include "xap_Strings.h"
 #include "xap_Win32DialogBase.h"
 #include "xap_Win32FrameImpl.h"
+#include "ut_Win32LocaleString.h"
 
-void XAP_Win32DialogBase::createModal(XAP_Frame* pFrame, LPCTSTR dlgTemplate)
+void XAP_Win32DialogBase::createModal(XAP_Frame* pFrame, LPCWSTR dlgTemplate)
 {
 	UT_ASSERT(m_tag == magic_tag);
 
@@ -42,8 +43,7 @@ void XAP_Win32DialogBase::createModal(XAP_Frame* pFrame, LPCTSTR dlgTemplate)
 	HWND hFrameWnd = pWin32FrameImpl->getTopLevelWindow();
 
 	// raise the dialog
-	const int result =
-		DialogBoxParam(pWin32App->getInstance(),
+	int result = DialogBoxParamW(pWin32App->getInstance(),
 						dlgTemplate,
 						hFrameWnd,
 						(DLGPROC)&XAP_Win32DialogBase::s_dlgProc,
@@ -54,31 +54,32 @@ void XAP_Win32DialogBase::createModal(XAP_Frame* pFrame, LPCTSTR dlgTemplate)
 }
 
 
-HWND XAP_Win32DialogBase::createModeless(XAP_Frame* pFrame, LPCTSTR dlgTemplate)
+HWND XAP_Win32DialogBase::createModeless(XAP_Frame* pFrame, LPCWSTR dlgTemplate)
 {
 	UT_ASSERT(m_tag == magic_tag);
+   	UT_return_val_if_fail(pFrame, NULL);
 
 	XAP_App* pApp = XAP_App::getApp();
-	UT_ASSERT(pApp);
+	UT_return_val_if_fail(pApp, NULL);
 
 	XAP_Win32App* pWin32App = static_cast<XAP_Win32App*>(pApp);
 
 	XAP_FrameImpl* pFrameImpl = pFrame->getFrameImpl();
 
-	UT_ASSERT(pFrame);
-
 	XAP_Win32FrameImpl* pWin32FrameImpl = static_cast<XAP_Win32FrameImpl*>(pFrameImpl);
 
 	HWND hFrameWnd = pWin32FrameImpl->getTopLevelWindow();
 
-	HWND hWnd =
-		CreateDialogParam(pWin32App->getInstance(),
+	HWND hWnd = CreateDialogParamW(pWin32App->getInstance(),
 							dlgTemplate,
 							hFrameWnd,
 							(DLGPROC)&XAP_Win32DialogBase::s_dlgProc,
 							(LPARAM)this);
-	// possibly we shouldn't check for success/failure here?
-	UT_ASSERT(hWnd != NULL);
+	UT_return_val_if_fail(hWnd, NULL);
+
+    m_hDlg = hWnd;
+	showWindow(SW_SHOW);
+	bringWindowToTop();
 
 	return hWnd;
 }
@@ -86,30 +87,20 @@ HWND XAP_Win32DialogBase::createModeless(XAP_Frame* pFrame, LPCTSTR dlgTemplate)
 
 BOOL CALLBACK XAP_Win32DialogBase::s_dlgProc(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
 {
-	static const char szProp[] = "abiWin23base_dlgproc";
-
-	XAP_Win32DialogBase* pThis;
+	XAP_Win32DialogBase* pThis = NULL;
 
 	if (msg == WM_INITDIALOG)
 	{
 		pThis = (XAP_Win32DialogBase*)lParam;
+        SetWindowLongW(hWnd, DWLP_USER, lParam);
 		pThis->m_hDlg = hWnd;
-		SetProp(hWnd, szProp, (HANDLE)lParam /* XAP_Win32DialogBase* */);
 		return pThis->_onInitDialog(hWnd, wParam, lParam);
 	}
-	else
-	{
-		pThis = (XAP_Win32DialogBase*)GetProp(hWnd, szProp);
-	}
 
-	if (!pThis)
-	{
-		// ... then we must assume this is some init out of our control,
-		// and pass it to the system
+    pThis = (XAP_Win32DialogBase *) GetWindowLongW(hWnd,DWLP_USER);
+	
+	if (pThis == NULL)
 		return FALSE;
-	}
-
-	UT_ASSERT(pThis);
 	UT_ASSERT(pThis->m_tag == magic_tag);
 
 
@@ -118,7 +109,6 @@ BOOL CALLBACK XAP_Win32DialogBase::s_dlgProc(HWND hWnd, UINT msg, WPARAM wParam,
 
 	case WM_COMMAND:
 		return pThis->_onCommand(hWnd, wParam, lParam);
-		break;
 
 	case WM_NOTIFY:
 		switch (((LPNMHDR)lParam)->code)
@@ -154,170 +144,221 @@ BOOL XAP_Win32DialogBase::_onDlgMessage(HWND /*hWnd*/, UINT /*msg*/, WPARAM /*wP
 
 void XAP_Win32DialogBase::checkButton(UT_sint32 controlId, bool bChecked)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_if_fail(IsWindow(m_hDlg));
 	CheckDlgButton(m_hDlg, controlId, bChecked ? BST_CHECKED : BST_UNCHECKED);
 }
 
 void XAP_Win32DialogBase::enableControl(UT_sint32 controlId, bool bChecked)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_if_fail(IsWindow(m_hDlg));
 	EnableWindow(GetDlgItem(m_hDlg, controlId), bChecked ? TRUE : FALSE);
 }
 
 void XAP_Win32DialogBase::destroyWindow()
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	DestroyWindow(m_hDlg);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	int iResult = DestroyWindow(m_hDlg);
+	UT_ASSERT_HARMLESS((iResult != 0));
 }
 
-void XAP_Win32DialogBase::setDialogTitle(LPCSTR p_str)
+void XAP_Win32DialogBase::setDialogTitle(const char* uft8_str)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SetWindowText(m_hDlg, p_str);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	UT_Win32LocaleString str;
+	str.fromUTF8 (uft8_str);
+	SetWindowTextW (m_hDlg, str.c_str());
 }
 
 int XAP_Win32DialogBase::showWindow(int Mode )
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_val_if_fail(IsWindow(m_hDlg), 0);
 	return ShowWindow(m_hDlg, Mode);
 }
 
 int XAP_Win32DialogBase::showControl(UT_sint32 controlId, int Mode)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_val_if_fail(IsWindow(m_hDlg), 0);
 	return ShowWindow(GetDlgItem(m_hDlg, controlId), Mode);
 }
 
-int XAP_Win32DialogBase::bringWindowToTop()
+int XAP_Win32DialogBase::bringWindowToTop()                     
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	const UINT uFlags =	SWP_NOMOVE |
-						SWP_NOOWNERZORDER |
-						SWP_NOSIZE |
-						SWP_NOACTIVATE;
-	return SetWindowPos(m_hDlg, HWND_TOP, 0, 0, 0, 0, uFlags);
+	UT_return_val_if_fail(IsWindow(m_hDlg), 0);
+    return BringWindowToTop(m_hDlg);
+}
+
+void XAP_Win32DialogBase::notifyCloseFrame(XAP_Frame *pFrame)
+{
+	if((HWND)GetWindowLongPtrW(m_hDlg, GWLP_HWNDPARENT) == static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow())
+	{
+		SetWindowLongPtrW(m_hDlg, GWLP_HWNDPARENT, NULL);
+		SetWindowPos(m_hDlg, NULL, 0, 0, 0, 0,
+						SWP_NOMOVE | SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE | SWP_FRAMECHANGED);
+	}
 }
 
 // Combo boxes.
 
 int XAP_Win32DialogBase::addItemToCombo(UT_sint32 controlId, LPCSTR p_str)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, CB_ADDSTRING, 0, (LPARAM)p_str);
+	UT_return_val_if_fail(IsWindow(m_hDlg), CB_ERR);
+    UT_Win32LocaleString str;
+	str.fromUTF8 (p_str); 	
+	return SendDlgItemMessageW(m_hDlg, controlId, CB_ADDSTRING, 0, (LPARAM)str.c_str());	
 }
 
 int XAP_Win32DialogBase::setComboDataItem(UT_sint32 controlId, int nIndex, DWORD dwData)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, CB_SETITEMDATA, nIndex, dwData);
+	UT_return_val_if_fail(IsWindow(m_hDlg), CB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, CB_SETITEMDATA, nIndex, dwData);
 }
 
 
 int XAP_Win32DialogBase::getComboDataItem(UT_sint32 controlId, int nIndex)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, CB_GETITEMDATA, nIndex,0);
+	UT_return_val_if_fail(IsWindow(m_hDlg), CB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, CB_GETITEMDATA, nIndex,0);
 }
 
 int XAP_Win32DialogBase::getComboItemIndex(UT_sint32 controlId, LPCSTR p_str)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, CB_FINDSTRINGEXACT, -1, (LPARAM) p_str);
+	UT_return_val_if_fail(IsWindow(m_hDlg), CB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, CB_FINDSTRINGEXACT, -1, (LPARAM) p_str);
 }
 
 void XAP_Win32DialogBase::selectComboItem(UT_sint32 controlId, int index)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, CB_SETCURSEL, index, 0);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, CB_SETCURSEL, index, 0);
 }
 
 int XAP_Win32DialogBase::getComboSelectedIndex(UT_sint32 controlId) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, CB_GETCURSEL, 0, 0);
+	UT_return_val_if_fail(IsWindow(m_hDlg), CB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, CB_GETCURSEL, 0, 0);
 }
 
 void XAP_Win32DialogBase::resetComboContent(UT_sint32 controlId)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, CB_RESETCONTENT, 0, 0);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, CB_RESETCONTENT, 0, 0);
+}
+
+void XAP_Win32DialogBase::getComboTextItem(UT_sint32 controlId, int index, UT_Win32LocaleString& str)
+{
+	UT_return_if_fail(IsWindow(m_hDlg));
+	wchar_t szBuff[1024];
+
+	if (SendDlgItemMessageW(m_hDlg, controlId, CB_GETLBTEXT, index, (LPARAM)szBuff) != CB_ERR)
+		str.fromLocale(szBuff);
+	else
+		str.clear();
 }
 
 // List boxes
 
 void XAP_Win32DialogBase::resetContent(UT_sint32 controlId)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, LB_RESETCONTENT, 0, 0);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, LB_RESETCONTENT, 0, 0);
 }
 
 
 int XAP_Win32DialogBase::addItemToList(UT_sint32 controlId, LPCSTR p_str)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, LB_ADDSTRING, 0, (LPARAM)p_str);
+	UT_return_val_if_fail(IsWindow(m_hDlg), LB_ERR);
+	UT_Win32LocaleString str;
+	str.fromUTF8(p_str);
+	return SendDlgItemMessageW(m_hDlg, controlId, LB_ADDSTRING, 0, (LPARAM)str.c_str());
 }
 
 int XAP_Win32DialogBase::setListDataItem(UT_sint32 controlId, int nIndex, DWORD dwData)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, LB_SETITEMDATA, nIndex, dwData);
+	UT_return_val_if_fail(IsWindow(m_hDlg), LB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, LB_SETITEMDATA, nIndex, dwData);
 }
 
 
 int XAP_Win32DialogBase::getListDataItem(UT_sint32 controlId, int nIndex)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, LB_GETITEMDATA, nIndex,0);
+	UT_return_val_if_fail(IsWindow(m_hDlg), LB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, LB_GETITEMDATA, nIndex,0);
 }
 
 int XAP_Win32DialogBase::getListSelectedIndex(UT_sint32 controlId) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	return SendDlgItemMessage(m_hDlg, controlId, LB_GETCURSEL, 0, 0);
+	UT_return_val_if_fail(IsWindow(m_hDlg), LB_ERR);
+	return SendDlgItemMessageW(m_hDlg, controlId, LB_GETCURSEL, 0, 0);
 }
 
 void XAP_Win32DialogBase::selectListItem(UT_sint32 controlId, int index)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, LB_SETCURSEL, index, 0);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, LB_SETCURSEL, index, 0);
 }
 
 void XAP_Win32DialogBase::getListText(UT_sint32 controlId, int index, char *p_str) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, LB_GETTEXT, index, (LPARAM)p_str);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, LB_GETTEXT, index, (LPARAM)p_str);
 }
 
 
 // Controls
 void XAP_Win32DialogBase::setControlText(UT_sint32 controlId, LPCSTR p_str)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SetDlgItemText(m_hDlg, controlId, p_str);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	//UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
+	UT_Win32LocaleString str;
+	str.fromUTF8(p_str);
+	SetDlgItemTextW(m_hDlg, controlId, str.c_str());
 }
 
+bool XAP_Win32DialogBase::setDlgItemText(int nIDDlgItem,  const char* uft8_str)
+{
+	UT_return_val_if_fail(IsWindow(m_hDlg), false);
+	
+	UT_Win32LocaleString str;
+	str.fromUTF8 (uft8_str);
+	return (bool) SetDlgItemTextW (m_hDlg, nIDDlgItem, str.c_str());
+}
+
+bool XAP_Win32DialogBase::getDlgItemText(int nIDDlgItem, UT_Win32LocaleString& str)
+{	
+	wchar_t szBuff [1024];	
+	bool rslt;
+	
+	rslt = (bool) GetDlgItemTextW(m_hDlg, nIDDlgItem, szBuff, 1024);
+	
+	if (rslt == true)
+		str.fromLocale(szBuff);
+	else
+		str.clear();
+	
+	return rslt;
+ }
+
 void XAP_Win32DialogBase::setControlInt(UT_sint32 controlId, int value)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_if_fail(IsWindow(m_hDlg));
 	SetDlgItemInt(m_hDlg, controlId, value, TRUE);
 }
 
 int XAP_Win32DialogBase::getControlInt(UT_sint32 controlId) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_val_if_fail(IsWindow(m_hDlg), 0);
 	return GetDlgItemInt(m_hDlg, controlId, NULL, FALSE);
 }
 
 void XAP_Win32DialogBase::selectControlText(UT_sint32 controlId, UT_sint32 start, UT_sint32 end)
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	SendDlgItemMessage(m_hDlg, controlId, EM_SETSEL, start,end);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	SendDlgItemMessageW(m_hDlg, controlId, EM_SETSEL, start,end);
 }
 
 int XAP_Win32DialogBase::isChecked(UT_sint32 controlId) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_val_if_fail(IsWindow(m_hDlg), 0);
 	return IsDlgButtonChecked(m_hDlg, controlId);
 }
 
@@ -326,20 +367,26 @@ bool XAP_Win32DialogBase::isDialogValid() const
 	return IsWindow(m_hDlg)!=0;
 }
 
-void XAP_Win32DialogBase::getControlText(	UT_sint32 controlId,
+void XAP_Win32DialogBase::getControlText(UT_sint32 controlId,
 											LPSTR p_buffer,
 											UT_sint32 Buffer_length) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
-	GetDlgItemText(m_hDlg, controlId, p_buffer, Buffer_length);
+	UT_return_if_fail(IsWindow(m_hDlg));
+	UT_Win32LocaleString str;
+	LPWSTR wbuf = (LPWSTR) UT_calloc(Buffer_length+1,2);
+	GetDlgItemTextW(m_hDlg, controlId, wbuf, Buffer_length);
+	str.fromLocale(wbuf);
+	strncpy(p_buffer,str.utf8_str().utf8_str(),Buffer_length);
+	FREEP(wbuf);
 }
 
 bool XAP_Win32DialogBase::isControlVisible(UT_sint32 controlId) const
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_val_if_fail(IsWindow(m_hDlg), false);
+
 	HWND hControl = GetDlgItem(m_hDlg, controlId);
 	if (hControl) {
-		return (GetWindowLong(m_hDlg, GWL_STYLE) & WS_VISIBLE) ?
+		return (GetWindowLongPtrW(m_hDlg, GWL_STYLE) & WS_VISIBLE) ?
 				true : false;
 	}
 	return false;
@@ -347,7 +394,7 @@ bool XAP_Win32DialogBase::isControlVisible(UT_sint32 controlId) const
 
 void XAP_Win32DialogBase::centerDialog()
 {
-	UT_ASSERT(IsWindow(m_hDlg));
+	UT_return_if_fail(IsWindow(m_hDlg));
 	
 	RECT 	rc, rcParent;
 	int 	nWidth, nHeight;
@@ -374,7 +421,6 @@ void XAP_Win32DialogBase::centerDialog()
 	pt.x -= nWidth / 2;
 	pt.y -= nHeight / 2;
 
-	// Move your arse...
 	MoveWindow (m_hDlg, pt.x, pt.y, nWidth, nHeight, TRUE);
 }
 
@@ -414,4 +460,38 @@ BOOL XAP_Win32DialogBase::_callHelp()
 	return TRUE;
 }
 
+bool XAP_Win32DialogBase::setWindowText (HWND hWnd, const char* uft8_str)
+{
+	UT_return_val_if_fail(IsWindow(hWnd), false);
+	
+	UT_Win32LocaleString str;
+	str.fromUTF8 (uft8_str);
+	return (bool) SetWindowTextW (hWnd, str.c_str());
+}
+
+bool XAP_Win32DialogBase::getDlgItemText(HWND hWnd, int nIDDlgItem, UT_Win32LocaleString& str)
+{	
+	UT_return_val_if_fail(IsWindow(hWnd), false);
+	
+	wchar_t szBuff [1024];	
+	bool rslt;
+	
+	rslt = (bool) GetDlgItemTextW(hWnd, nIDDlgItem, szBuff, 1024);
+	
+	if (rslt == true)
+		str.fromLocale(szBuff);
+	else
+		str.clear();
+	
+	return rslt;
+}
+
+bool XAP_Win32DialogBase::setDlgItemText(HWND hWnd, int nIDDlgItem,  const char* uft8_str)
+{
+	UT_return_val_if_fail(IsWindow(hWnd), false);
+	
+	UT_Win32LocaleString str;
+	str.fromUTF8 (uft8_str);
+	return (bool) SetDlgItemTextW (hWnd, nIDDlgItem, str.c_str());
+}
 
