@@ -36,6 +36,8 @@
 #include "ut_debugmsg.h"
 #include "ut_path.h"
 #include "ut_Win32OS.h"
+#include "ut_Win32LocaleString.h"
+#include "xap_Win32DialogBase.h"
 #include "xap_ViewListener.h"
 #include "ev_EditMethod.h"
 #include "xav_View.h"
@@ -89,7 +91,7 @@ LRESULT CALLBACK s_rebarWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM
 		case WM_DRAWITEM:
 		{
 			 DRAWITEMSTRUCT* pDrawItem = (DRAWITEMSTRUCT*)lParam;
-			 SendMessage(pDrawItem->hwndItem, WM_DRAWITEM, wParam, lParam);
+			 SendMessageW(pDrawItem->hwndItem, WM_DRAWITEM, wParam, lParam);
 			 return TRUE;
 		}
 
@@ -109,10 +111,7 @@ LRESULT CALLBACK s_rebarWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM
 			break;		
 	}
 
-	if(UT_IsWinNT())
-		return CallWindowProcW(s_oldRedBar, hWnd, uMessage, wParam, lParam);
-	else
-		return CallWindowProc(s_oldRedBar, hWnd, uMessage, wParam, lParam);
+	return CallWindowProcW(s_oldRedBar, hWnd, uMessage, wParam, lParam);
 }
 
 
@@ -150,8 +149,7 @@ XAP_Win32FrameImpl::~XAP_Win32FrameImpl(void)
 
 	// have to reset the window long, so our message functions do not
 	// try to derefernce it
-	SetWindowLong(m_hwndFrame, GWL_USERDATA,0);
-
+	SetWindowLongPtrW(m_hwndFrame, GWLP_USERDATA,0);
 }
 
 
@@ -176,8 +174,8 @@ bool XAP_Win32FrameImpl::_updateTitle(void)
 
 	UT_UTF8String sTmp = pFrame->getTitle();
 	sTmp += " - ";
-	sTmp += XAP_App::getApp()->getApplicationTitleForTitleBar();
-	UT_SetWindowText(m_hwndFrame, sTmp.utf8_str());
+    sTmp += XAP_App::getApp()->getApplicationTitleForTitleBar();	
+	XAP_Win32DialogBase::setWindowText (m_hwndFrame, sTmp.utf8_str());
 
 	return true;
 }
@@ -223,6 +221,37 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 		iHeight = CW_USEDEFAULT;
 		iPosX = CW_USEDEFAULT;
 		iPosY = CW_USEDEFAULT;
+	} else {
+		// Ensure the window fits current desktop area
+		RECT rcDesktop, rcWindow;
+#if (_WIN32_WINNT >= 0x0500)
+		rcDesktop.left=rcDesktop.right=0;
+
+		if (GetSystemMetrics(SM_CMONITORS)>1) {
+			HMONITOR m;
+			MONITORINFO mif;
+			SetRect(&rcWindow,iPosX,iPosY,iPosX+iWidth,iPosY+iHeight);
+			if (m=MonitorFromRect(&rcWindow,MONITOR_DEFAULTTONEAREST)) {;
+				mif.cbSize=sizeof(MONITORINFO);
+				if (GetMonitorInfoW(m,&mif)) {
+					rcDesktop=mif.rcWork;
+				}
+			}
+		}
+
+		if (rcDesktop.left==rcDesktop.right)
+#endif
+			if (!SystemParametersInfoW(SPI_GETWORKAREA,0,&rcDesktop,0))
+				SetRect(&rcDesktop,0,0,GetSystemMetrics(SM_CXSCREEN),GetSystemMetrics(SM_CYSCREEN));
+
+		if (iWidth > (rcDesktop.right-rcDesktop.left)) iWidth=rcDesktop.right-rcDesktop.left;
+		if (iHeight > (rcDesktop.bottom-rcDesktop.top)) iHeight=rcDesktop.bottom-rcDesktop.top;
+
+		if (iPosX+iWidth > rcDesktop.right) iPosX=rcDesktop.right-iWidth;
+		if (iPosY+iHeight > rcDesktop.bottom) iPosY=rcDesktop.bottom-iHeight;
+
+		if (iPosX < rcDesktop.left) iPosX=rcDesktop.left;
+		if (iPosY < rcDesktop.top)  iPosY=rcDesktop.top;
 	}
 	/* let Windows(R) place the Window for all but 1st one, for stairstep effect */
 	if (!firstWindow)
@@ -237,7 +266,11 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 
 	XAP_Win32App *pWin32App = static_cast<XAP_Win32App *>(XAP_App::getApp());
 
-	m_hwndFrame = UT_CreateWindowEx(0L, pWin32App->getApplicationName(), pWin32App->getApplicationTitleForTitleBar(),
+	UT_Win32LocaleString str, title;
+	str.fromASCII (pWin32App->getApplicationName());	
+	title.fromASCII (pWin32App->getApplicationTitleForTitleBar());
+		
+	m_hwndFrame = UT_CreateWindowEx(0L, str.c_str(), title.c_str(),
 									WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN,
 									iPosX, iPosY, iWidth, iHeight,
 									NULL, NULL, pWin32App->getInstance(), NULL);
@@ -246,10 +279,15 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 
 	// bind this frame to its window
 	// WARNING: We assume in many places this refers to a XAP_Frame or descendant!!!
-	//SetWindowLong(m_hwndFrame, GWL_USERDATA,(LONG)this);
-	SetWindowLong(m_hwndFrame, GWL_USERDATA,(LONG)getFrame());
+	//SetWindowLongPtrW(m_hwndFrame, GWLP_USERDATA,(LONG_PTR)this);
+	SetWindowLongPtrW(m_hwndFrame, GWLP_USERDATA,(LONG_PTR)getFrame());
 
-	m_mouseWheelMessage = RegisterWindowMessage(MSH_MOUSEWHEEL);
+#ifndef UNICODE
+	// remove this when we are a true unicode app
+	m_mouseWheelMessage = RegisterWindowMessageW(L"MSWHEEL_ROLLMSG");
+#else
+	m_mouseWheelMessage = RegisterWindowMessageW(MSH_MOUSEWHEEL);
+#endif
 
 	// synthesize a menu from the info in our
 	// base class and install it into the window.
@@ -270,7 +308,7 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 	}
 
 	// create a rebar container for all the toolbars
-	m_hwndRebar = UT_CreateWindowEx(0L, REBARCLASSNAME, NULL,
+	m_hwndRebar = UT_CreateWindowEx(0L, REBARCLASSNAMEW, NULL,
 									WS_VISIBLE | WS_BORDER | WS_CHILD | WS_CLIPCHILDREN |
 									WS_CLIPSIBLINGS | CCS_NODIVIDER | CCS_NOPARENTALIGN |
 									RBS_VARHEIGHT | RBS_BANDBORDERS,
@@ -279,8 +317,8 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 	UT_ASSERT(m_hwndRebar);
 	
 	/* override the window procedure*/
-	s_oldRedBar = (WHICHPROC)GetWindowLong(m_hwndRebar, GWL_WNDPROC);
-	SetWindowLong(m_hwndRebar, GWL_WNDPROC, (LONG)s_rebarWndProc);
+	s_oldRedBar = (WHICHPROC)GetWindowLongPtrW(m_hwndRebar, GWLP_WNDPROC);
+	SetWindowLongPtrW(m_hwndRebar, GWLP_WNDPROC, (LONG_PTR)s_rebarWndProc);
 
 	// create a toolbar instance for each toolbar listed in our base class.
 
@@ -419,7 +457,7 @@ EV_Menu* XAP_Win32FrameImpl::_getMainMenu(void)
 // resized in order to fill the gap leaved by the statusbar
 void XAP_Win32FrameImpl::_queue_resize(void)
 {
-	::SendMessage(m_hwndFrame, WM_SIZE, 0, MAKELONG(m_iRealSizeWidth, m_iRealSizeHeight));
+	::SendMessageW(m_hwndFrame, WM_SIZE, 0, MAKELONG(m_iRealSizeWidth, m_iRealSizeHeight));
 }
 
 
@@ -462,7 +500,7 @@ void XAP_Win32FrameImpl::_setFullScreen(bool isFullScreen)
 	HWND hwndFrame = static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow();
 
 	// Get the window's style so we can add or remove the titlebar later
-	long hStyle = GetWindowLong(hwndFrame, GWL_STYLE);
+	long hStyle = GetWindowLongPtrW(hwndFrame, GWL_STYLE);
 
 	if (isFullScreen)
 	{
@@ -503,7 +541,7 @@ void XAP_Win32FrameImpl::_setFullScreen(bool isFullScreen)
 	}
 
 	// Add or remove title-bar and border
-	SetWindowLong(hwndFrame, GWL_STYLE, isFullScreen ? hStyle & ~WS_CAPTION : hStyle | WS_CAPTION);
+	SetWindowLongPtrW(hwndFrame, GWL_STYLE, isFullScreen ? hStyle & ~WS_CAPTION : hStyle | WS_CAPTION);
 
 	// We hide the window before maximizing
 	// to ensure it displays with the proper geometry
@@ -549,9 +587,9 @@ void XAP_Win32FrameImpl::_nullUpdate (void) const
 	MSG msg;
 	for( int i = 0 ; i < 10 ; i++ )
 	{
-		if( PeekMessage( &msg, (HWND) NULL, 0, 0, PM_REMOVE) )
+		if( PeekMessageW( &msg, (HWND) NULL, 0, 0, PM_REMOVE) )
 		{
-			DispatchMessage(&msg); 
+			DispatchMessageW(&msg); 
 		} 
 	}
 }
@@ -595,7 +633,7 @@ bool XAP_Win32FrameImpl::_RegisterClass(XAP_Win32App * app)
 {
 	ATOM a = UT_RegisterClassEx(CS_DBLCLKS, XAP_Win32FrameImpl::_FrameWndProc, app->getInstance(),
 								app->getIcon(), LoadCursor(NULL,IDC_ARROW), (HBRUSH)(COLOR_BTNFACE+1), app->getSmallIcon(),
-								NULL, app->getApplicationName());
+								NULL, /*app->getApplicationName()*/ L"Abiword");
 	
 	UT_return_val_if_fail(a, false);
 
@@ -646,8 +684,7 @@ void XAP_Win32FrameImpl::_rebuildMenus(void)
 
 LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
 {
-	XAP_Frame * f = (XAP_Frame*)GetWindowLong(hwnd, GWL_USERDATA);
-
+	XAP_Frame * f = (XAP_Frame*)GetWindowLongPtrW(hwnd, GWLP_USERDATA);
 	if (!f)
 	{
 		return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
@@ -663,7 +700,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 	if(iMsg == fimpl->m_mouseWheelMessage)
 	{
 		wParam = MAKEWPARAM(0, (short)(int)wParam);
-		return SendMessage(hwnd, WM_MOUSEWHEEL, wParam, lParam);
+		return SendMessageW(hwnd, WM_MOUSEWHEEL, wParam, lParam);
 	}
 
 	switch (iMsg)
@@ -799,14 +836,13 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 		case TBN_DROPDOWN:
 		{
 			HWND hWnd = ((LPNMHDR) lParam)->hwndFrom;
-			EV_Win32Toolbar * t = (EV_Win32Toolbar *)GetWindowLong(hWnd, GWL_USERDATA);						
-			t->onDropArrow(((LPNMTOOLBAR) lParam)->iItem);			
+			EV_Win32Toolbar * t = (EV_Win32Toolbar *)GetWindowLongPtrW(hWnd, GWLP_USERDATA);						
+			t->onDropArrow(((LPNMTOOLBARW) lParam)->iItem);			
 			Sleep(500); /* At least, half second where the arrow is shown as pressed*/			
 			return TBDDRET_DEFAULT;			/* Windows restores the pushed button*/
-			
 		}
 
-		case TTN_NEEDTEXT:
+		case TTN_NEEDTEXTW:
 			{
 				UT_uint32 nrToolbars, k;
 				nrToolbars = fimpl->m_vecToolbars.getItemCount();
@@ -843,7 +879,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 
 		case NM_CUSTOMDRAW:
 			{
-				LPNMCUSTOMDRAW  pNMcd = (LPNMCUSTOMDRAW)lParam;
+				LPNMCUSTOMDRAW pNMcd = (LPNMCUSTOMDRAW)lParam;
 				UT_uint32 nrToolbars, k;
 				nrToolbars = fimpl->m_vecToolbars.getItemCount();
 				for (k=0; k < nrToolbars; k++)
@@ -864,7 +900,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 							rc.bottom = pNMcd->rc.bottom;
 							hBr = GetSysColorBrush( COLOR_3DFACE );
 
-							HWND  hWndChild = FindWindowEx( pNMcd->hdr.hwndFrom, NULL, NULL, NULL );
+							HWND  hWndChild = FindWindowExW( pNMcd->hdr.hwndFrom, NULL, NULL, NULL );
 							while( hWndChild != NULL )
 							{
 								RECT   rcChild;
@@ -879,7 +915,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 								ScreenToClient( pNMcd->hdr.hwndFrom, &pt );
 								rc.right = pt.x;
 								FillRect( pNMcd->hdc, &rc, hBr );
-								hWndChild = FindWindowEx( pNMcd->hdr.hwndFrom, hWndChild, NULL, NULL );
+								hWndChild = FindWindowExW( pNMcd->hdr.hwndFrom, hWndChild, NULL, NULL );
 							}
 
 							/* Don't delete hBr since it was obtained using GetSysColorBrush, so System owned */
@@ -982,16 +1018,16 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 
 	case WM_MOUSEWHEEL:
 	{
-		return SendMessage(fimpl->m_hwndContainer, iMsg, wParam, lParam);
+		return SendMessageW(fimpl->m_hwndContainer, iMsg, wParam, lParam);
 	}
 
 	case WM_SYSCOLORCHANGE:
 	{
 		if (fimpl->m_hwndRebar)
 		{
-			SendMessage(fimpl->m_hwndRebar,WM_SYSCOLORCHANGE,0,0);
+			SendMessageW(fimpl->m_hwndRebar,WM_SYSCOLORCHANGE,0,0);
 
-			REBARBANDINFO rbbi;
+			REBARBANDINFOW rbbi;
 			memset(&rbbi, 0, sizeof(rbbi));
 
 			rbbi.cbSize = sizeof(REBARBANDINFO);
@@ -1001,29 +1037,30 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 
 			UT_uint32 nrToolbars = fimpl->m_vecToolbars.getItemCount();
 			for (UT_uint32 k=0; k < nrToolbars; k++)
-				SendMessage(fimpl->m_hwndRebar, RB_SETBANDINFO,k,(LPARAM)&rbbi);
+				SendMessageW(fimpl->m_hwndRebar, RB_SETBANDINFO,k,(LPARAM)&rbbi);
 		}
 
 		if (fimpl->m_hwndContainer)
-			SendMessage(fimpl->m_hwndContainer,WM_SYSCOLORCHANGE,0,0);
+			SendMessageW(fimpl->m_hwndContainer,WM_SYSCOLORCHANGE,0,0);
 		if (fimpl->m_hwndStatusBar)
-			SendMessage(fimpl->m_hwndStatusBar,WM_SYSCOLORCHANGE,0,0);
+			SendMessageW(fimpl->m_hwndStatusBar,WM_SYSCOLORCHANGE,0,0);
 		return 0;
 	}
 
-	case WM_DROPFILES:
+	case WM_DROPFILES:              //TODO: CHECK
 		{
 			HDROP hDrop = (HDROP) wParam; 
 			// How many files were dropped?
-			int count = DragQueryFile(hDrop, 0xFFFFFFFF, NULL, 0);
-			char szFileName[PATH_MAX];
+			int count = DragQueryFileW(hDrop, 0xFFFFFFFF, NULL, 0);
+			WCHAR szFileName[PATH_MAX];
+			UT_Win32LocaleString str;
 			int i,pathlength;
 			for (i=0; i<count; i++)
 			{
-				pathlength = DragQueryFile(hDrop, i, NULL, 0);
+				pathlength = DragQueryFileW(hDrop, i, NULL, 0);
 				if (pathlength < PATH_MAX)
 				{
-					DragQueryFile(hDrop, i, szFileName, PATH_MAX);
+					DragQueryFileW(hDrop, i, szFileName, PATH_MAX);
 					XAP_App * pApp = XAP_App::getApp();
 					UT_return_val_if_fail(pApp, 0);
 					FV_View* pCurrentView = (FV_View *) f->getCurrentView();
@@ -1039,7 +1076,8 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 						in the document, if not we assume that it's a document 		
 					*/								
 					// If there is no import graphic, it's a document...
-					char * uri = UT_go_filename_to_uri(AP_Win32App::s_fromWinLocaleToUTF8(szFileName).utf8_str());
+					str.fromLocale(szFileName);
+					char * uri = UT_go_filename_to_uri(str.utf8_str().utf8_str());
 					if(uri)
 						errorCode = IE_ImpGraphic::constructImporter(uri, iegft, &pIEG);
 
