@@ -98,6 +98,8 @@ XAP_App::XAP_App(const char * szAppName)
 	  m_bDebugBool(false),
 	  m_bBonoboRunning(false),
 	  m_bEnableSmoothScrolling(true),
+      m_bDisableDoubleBuffering(false),
+      m_bNoGUI(false),
 	  m_pKbdLang(NULL), // must not be deleted by destructor !!!
  	  m_pUUIDGenerator(NULL),
 	  m_pGraphicsFactory(NULL),
@@ -366,9 +368,9 @@ bool XAP_App::initialize(const char * szKeyBindingsKey, const char * szKeyBindin
 	bool bResult;
 	bResult = m_pInputModes->createInputMode(szBindings,pBindingMap);
 	UT_ASSERT(bResult);
-	bool bResult2;
-	bResult2 = m_pInputModes->setCurrentMap(szBindings);
-	UT_ASSERT(bResult2);
+	bResult = m_pInputModes->setCurrentMap(szBindings);
+	UT_ASSERT(bResult);
+	UT_UNUSED(bResult); // TODO deal with the error
 
 	// check if the prefs are set to use specific graphics class
 	const char * pszGraphics = NULL;
@@ -1661,3 +1663,29 @@ void XAP_App::_fundamentalAsserts() const
 	UT_ASSERT(sizeof(gchar) == sizeof(char));
 }
 #endif
+
+bool
+XAP_App::getDisableDoubleBuffering() const
+{
+    return m_bDisableDoubleBuffering;
+}
+
+void
+XAP_App::setDisableDoubleBuffering( bool v )
+{
+    m_bDisableDoubleBuffering = v;
+}
+
+bool
+XAP_App::getNoGUI() const
+{
+    return m_bNoGUI;
+}
+
+void
+XAP_App::setNoGUI( bool v )
+{
+    setDisableDoubleBuffering(true);
+    m_bNoGUI = v;
+}
+
