@@ -1,5 +1,6 @@
 /* AbiSource Application Framework
  * Copyright (C) 1998 AbiSource, Inc.
+ * Copyright (C) 2009 Hubert Figuiere
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -62,7 +63,7 @@ typedef UT_uint32			XAP_String_Id;
 // base class provides interface regardless of how we got the strings
 //////////////////////////////////////////////////////////////////
 
-class XAP_StringSet
+class ABI_EXPORT XAP_StringSet
 {
 public:
 	XAP_StringSet(XAP_App * pApp, const gchar * szLanguageName);
@@ -73,6 +74,7 @@ public:
 	virtual const gchar *	getValue(XAP_String_Id id) const = 0;
 
 	bool getValue(XAP_String_Id id, const char * inEncoding, UT_String &s) const;
+	bool getValueUTF8(XAP_String_Id id, std::string &s) const;
 	bool getValueUTF8(XAP_String_Id id, UT_UTF8String &s) const;
 
 	void setEncoding(const char * inEndcoding);
@@ -90,7 +92,7 @@ protected:
 // a sub-class to wrap the compiled-in (english) strings
 //////////////////////////////////////////////////////////////////
 
-class XAP_BuiltinStringSet : public XAP_StringSet
+class ABI_EXPORT XAP_BuiltinStringSet : public XAP_StringSet
 {
 public:
 	XAP_BuiltinStringSet(XAP_App * pApp, const gchar * szLanguageName);
@@ -106,7 +108,7 @@ private:
 // a sub-class to deal with disk-based string sets (translations)
 //////////////////////////////////////////////////////////////////
 
-class XAP_DiskStringSet : public XAP_StringSet, public UT_XML::Listener
+class ABI_EXPORT XAP_DiskStringSet : public XAP_StringSet, public UT_XML::Listener
 {
 public:
 	XAP_DiskStringSet(XAP_App * pApp);
