@@ -69,6 +69,7 @@ fl_AutoNum::fl_AutoNum(	UT_uint32 id,
 		m_pParentItem(0)
 {
 	_setParent(pParent);
+	UT_ASSERT(m_pDoc);
 	memset(m_pszDelim, 0, 80);
 	memset(m_pszDecimal, 0, 80);
 	strncpy( m_pszDelim, lDelim, 80);
@@ -106,7 +107,7 @@ fl_AutoNum::fl_AutoNum(	UT_uint32 id,
 	// Set in Block???
 	memset(m_pszDelim, 0, 80);
 	memset(m_pszDecimal, 0, 80);
-
+	UT_ASSERT(m_pDoc);
 	if (lDelim)
 		strncpy( m_pszDelim, lDelim, 80);
 
@@ -448,7 +449,7 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 	}
 
 	UT_sint32 place = getPositionInList(pLayout,depth);
-	if(place == -1)
+	if (place == -1)
 	{
 		//	       UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		labelStr[0] = 0;
@@ -461,9 +462,14 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 	if(IS_NUMBERED_LIST_TYPE(m_List_Type))
 	{
 		psz = strlen(leftDelim);
-		for (i = 0; i < psz; i++)
+		char *pSrc = leftDelim;
+		char *pLim = leftDelim + psz;
+		while (pSrc < pLim)
 		{
-			labelStr[(*insPoint)++] = CONV_TO_UCS leftDelim[i];
+			UT_UCS4Char ch = g_utf8_get_char_validated(pSrc,pLim-pSrc);
+			if (((signed)ch) < 0) ch=UCS_REPLACECHAR;
+			labelStr[(*insPoint)++] = ch;
+			pSrc = g_utf8_next_char(pSrc);
 		}
 	}
 	switch( m_List_Type)
@@ -595,9 +601,14 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 	    (g_ascii_strncasecmp(m_pszDecimal,rightDelim,4) != 0 || depth == 0) )
 	{
 		psz = strlen(rightDelim);
-		for (i = 0; i < psz; i++)
+		char *pSrc = rightDelim;
+		char *pLim = rightDelim + psz;
+		while (pSrc < pLim)
 		{
-			labelStr[(*insPoint)++] =  CONV_TO_UCS rightDelim[i];
+			UT_UCS4Char ch = g_utf8_get_char_validated(pSrc,pLim-pSrc);
+			if (((signed)ch) < 0) ch=UCS_REPLACECHAR;
+			labelStr[(*insPoint)++] = ch;
+			pSrc = g_utf8_next_char(pSrc);
 		}
 	}
 	labelStr[(*insPoint)] = 0;
@@ -746,7 +757,8 @@ void fl_AutoNum::insertItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pPrev, bo
 		{
 			pAuto->setParentItem(pItem);
 			pAuto->m_bDirty = true;
-			pAuto->_updateItems(0,NULL);
+			if(!pAuto->_updateItems(0,NULL))
+				return;
 		}
 	}
 
@@ -786,7 +798,8 @@ void fl_AutoNum::prependItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pNext, b
 			{
 				pAuto->setParentItem(pItem);
 				pAuto->m_bDirty = true;
-				pAuto->_updateItems(0,NULL);
+				if(	pAuto->_updateItems(0,NULL))
+					return;
 			}
 		}
 	}
@@ -843,7 +856,8 @@ void fl_AutoNum::removeItem(PL_StruxDocHandle pItem)
 				pAuto->setParentItem(getParentItem());
 			}
 			if(m_pDoc->areListUpdatesAllowed() == true)
-				pAuto->_updateItems(0,NULL);
+				if(!pAuto->_updateItems(0,NULL))
+					return;
 		}
 	}
 	_updateItems(ndx,NULL);
@@ -940,9 +954,9 @@ const fl_AutoNum* fl_AutoNum::getAutoNumFromSdh(PL_StruxDocHandle sdh) const
 	return pAuto;
 }
 
-PL_StruxDocHandle fl_AutoNum::getLastItemInHeiracy(void)
+PL_StruxDocHandle fl_AutoNum::getLastItemInHeiracy(void) const
 {
-       fl_AutoNum * pAuto = this;
+       const fl_AutoNum * pAuto = this;
        PL_StruxDocHandle  pLastItem = NULL;
        bool bLoop = true;
        fl_AutoNum * pNext = NULL;
@@ -976,7 +990,7 @@ bool fl_AutoNum::isItem(PL_StruxDocHandle pItem) const
 		return true;
 }
 
-bool fl_AutoNum::isEmpty()
+bool fl_AutoNum::isEmpty() const
 {
 	if (m_pItems.getItemCount() > 0)
 		return false;
@@ -991,7 +1005,7 @@ PL_StruxDocHandle fl_AutoNum::getFirstItem() const
 }
 
 
-PL_StruxDocHandle fl_AutoNum::getLastItem()
+PL_StruxDocHandle fl_AutoNum::getLastItem() const
 {
 	UT_uint32 i = m_pItems.getItemCount();
 	if(i == 0 )
@@ -1002,7 +1016,7 @@ PL_StruxDocHandle fl_AutoNum::getLastItem()
 	}
 }
 
-bool fl_AutoNum::doesItemHaveLabel( fl_BlockLayout * pItem)
+bool fl_AutoNum::doesItemHaveLabel( fl_BlockLayout * pItem) const
 {
 	fp_Run * pRun = pItem->getFirstRun();
 	bool bStop = false;
@@ -1028,7 +1042,7 @@ bool fl_AutoNum::doesItemHaveLabel( fl_BlockLayout * pItem)
 }
 
 
-bool fl_AutoNum::isLastOnLevel(PL_StruxDocHandle pItem)
+bool fl_AutoNum::isLastOnLevel(PL_StruxDocHandle pItem) const
 {
 	UT_sint32 itemloc = m_pItems.findItem(const_cast<void *>(pItem));
 	if (itemloc == -1)
@@ -1039,7 +1053,7 @@ bool fl_AutoNum::isLastOnLevel(PL_StruxDocHandle pItem)
 		return false;
 }
 
-fl_AutoNum * fl_AutoNum::getActiveParent(void)
+fl_AutoNum * fl_AutoNum::getActiveParent(void) const
 {
 	fl_AutoNum * pAutoNum = m_pParent;
 
@@ -1053,9 +1067,9 @@ fl_AutoNum * fl_AutoNum::getActiveParent(void)
  * This method returns true if the requested ID is somewhere in this
  * List heiracy.
  */
-bool fl_AutoNum::isIDSomeWhere(UT_uint32 ID)
+bool fl_AutoNum::isIDSomeWhere(UT_uint32 ID) const
 {
-	fl_AutoNum * pAuto = this;
+	const fl_AutoNum * pAuto = this;
 	while(pAuto != NULL)
 	{
 		if(pAuto->getID() == ID)
@@ -1120,8 +1134,10 @@ void fl_AutoNum::update(UT_uint32 start)
 	if (isUpdating())
 		return;
 	//_calculateLabelStr(0);
-	_updateItems(start, NULL);
+	if(!_updateItems(start, NULL))
+		return;
 	void * sdh = const_cast<void *>( getFirstItem());
+	UT_return_if_fail(sdh);
 	if (m_pParent && !m_pParent->isUpdating())
 	{
 		UT_uint32 ndx = m_pParent->m_pItems.findItem(sdh);
@@ -1129,10 +1145,11 @@ void fl_AutoNum::update(UT_uint32 start)
 	}
 }
 
-void fl_AutoNum::_updateItems(UT_sint32 start, PL_StruxDocHandle notMe)
+bool fl_AutoNum::_updateItems(UT_sint32 start, PL_StruxDocHandle notMe)
 {
 	//	UT_DEBUGMSG(("Entering _updateItems\n"));
 	UT_sint32 j;
+	UT_return_val_if_fail(m_pDoc,false);
 	if(m_pDoc->areListUpdatesAllowed() == true)
 	{
 		//if(start == 0)
@@ -1158,19 +1175,21 @@ void fl_AutoNum::_updateItems(UT_sint32 start, PL_StruxDocHandle notMe)
 				UT_ASSERT_HARMLESS(pAuto);
 				if( pAuto && (pItem == pAuto->getParentItem()) && (pItem != notMe))
 				{
-					pAuto->_updateItems(0,pItem);
+					if(!pAuto->_updateItems(0,pItem))
+						return false;
 				}
 			}
 		}
 		m_bUpdatingItems = false;
 		m_bDirty = false;
 	}
+	return true;
 }
 
 ///
 /// Returns true if item is contained or immediately adjacent to the list
 ///
-bool fl_AutoNum::isContainedByList(PL_StruxDocHandle pItem)
+bool fl_AutoNum::isContainedByList(PL_StruxDocHandle pItem) const
 {
 	PL_StruxDocHandle sdh, sdh_prev,sdh_next;
 	PT_DocPosition pos_prev,pos_next,pos;
@@ -1195,7 +1214,7 @@ bool fl_AutoNum::isContainedByList(PL_StruxDocHandle pItem)
 }
 
 
-PL_StruxDocHandle fl_AutoNum::getNthBlock( UT_sint32 list_num)
+PL_StruxDocHandle fl_AutoNum::getNthBlock( UT_sint32 list_num) const
 {
 	if(list_num >= m_pItems.getItemCount())
 		return static_cast<PL_StruxDocHandle>(NULL);
@@ -1203,7 +1222,7 @@ PL_StruxDocHandle fl_AutoNum::getNthBlock( UT_sint32 list_num)
 		return static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(list_num));
 }
 
-PL_StruxDocHandle fl_AutoNum::getPrevInList( PL_StruxDocHandle pItem)
+PL_StruxDocHandle fl_AutoNum::getPrevInList( PL_StruxDocHandle pItem) const
 {
 	UT_sint32 itemloc = m_pItems.findItem(const_cast<void *>(pItem));
 	if (itemloc == -1 || itemloc == 0)
@@ -1211,10 +1230,10 @@ PL_StruxDocHandle fl_AutoNum::getPrevInList( PL_StruxDocHandle pItem)
 	return static_cast<PL_StruxDocHandle>(m_pItems.getNthItem( static_cast<UT_uint32>(itemloc) - 1));
 }
 
-inline UT_uint32 fl_AutoNum::_getLevelValue(fl_AutoNum * pAutoNum)
+inline UT_uint32 fl_AutoNum::_getLevelValue(fl_AutoNum * pAutoNum) const
 {
 	PL_StruxDocHandle pBlock = const_cast<PL_StruxDocHandle>(getFirstItem());
-	fl_AutoNum * pCurr = this;
+	const fl_AutoNum * pCurr = this;
 
 	while (1)
 	{
@@ -1408,7 +1427,7 @@ void fl_AutoNum::dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint
  *          to mess with that class at this very moment.
  */
 void fl_AutoNum::getAttributes (std::vector<UT_UTF8String> & v,
-								bool bEscapeXML)
+								bool bEscapeXML) const
 {
 	char szID[15], szPid[15], szType[5], szStart[5];
 
