@@ -1,3 +1,4 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * 
@@ -98,9 +99,11 @@ fl_DocListener::fl_DocListener(PD_Document* doc, FL_DocLayout *pLayout)
 	  {
 	      if(m_pLayout->getView()->getParentData())
 	      {
-		  AP_FrameData * pData =  static_cast<AP_FrameData *>(static_cast<XAP_Frame *>(m_pLayout->getView()->getParentData())->getFrameData());
-		  m_pStatusBar = static_cast<AP_StatusBar *>(pData->m_pStatusBar);
-	      }
+			  if( AP_FrameData * pData =  static_cast<AP_FrameData *>(static_cast<XAP_Frame *>(m_pLayout->getView()->getParentData())->getFrameData()))
+			  {
+				  m_pStatusBar = static_cast<AP_StatusBar *>(pData->m_pStatusBar);
+			  }
+		  }
 	  }
 	}
 	m_iFilled = 0;
@@ -935,7 +938,7 @@ bool fl_DocListener::change(PL_StruxFmtHandle sfh,
 	
 	bool bResult = false;
 	AV_ChangeMask chgMask = AV_CHG_NONE;
-	
+
 	switch (pcr->getType())
 	{
 	case PX_ChangeRecord::PXT_GlobMarker:
@@ -1349,7 +1352,7 @@ bool fl_DocListener::change(PL_StruxFmtHandle sfh,
 				fl_HdrFtrSectionLayout * pHdr = pCLSL->getHdrFtrSectionLayout();
 				bResult = pHdr->bl_doclistener_changeStrux( pCL, pcrxc);
 			}
-			else 
+			else
 				bResult = pCLSL->bl_doclistener_changeStrux(pCL, pcrxc);
 			goto finish_up;
 		}
