@@ -51,6 +51,7 @@ class fl_CharWidths;
 class fd_Field;
 class fp_HyperlinkRun;
 class fp_AnnotationRun;
+class fp_RDFAnchorRun;
 
 struct fp_RunSplitInfo
 {
@@ -94,7 +95,8 @@ enum FP_RUN_TYPE
 enum FP_HYPERLINK_TYPE
 {
     HYPERLINK_NORMAL =1,
-    HYPERLINK_ANNOTATION = 2
+    HYPERLINK_ANNOTATION = 2,
+    HYPERLINK_RDFANCHOR = 3
 };
 
 // specifies how setX should handle screen clearing
@@ -122,6 +124,7 @@ enum FPRUN_CLEAR_SCREEN
 		fp_BookmarkRun
 		fp_HyperlinkRun
 		fp_AnnotationRun
+		fp_RDFAnchorRun
 		fp_DummyRun
 
 	As far as the formatter's concerned, each subclass behaves somewhat
@@ -271,27 +274,27 @@ public:
 	bool			    isTopline(void) const ;
 	bool			    isBottomline(void) const ;
 	void			    setLinethickness(UT_sint32 max_linethickness);
-    UT_sint32		    getLinethickness(void) ;
+    UT_sint32		    getLinethickness(void) const;
 	void			    setUnderlineXoff(UT_sint32 xoff);
-	UT_sint32		    getUnderlineXoff(void);
+	UT_sint32		    getUnderlineXoff(void) const;
 	void			    setOverlineXoff(UT_sint32 xoff) ;
-	UT_sint32		    getOverlineXoff(void) ;
+	UT_sint32		    getOverlineXoff(void) const;
 	void			    setMaxUnderline(UT_sint32 xoff) ;
-	UT_sint32		    getMaxUnderline(void) ;
+	UT_sint32		    getMaxUnderline(void) const;
 	void			    setMinOverline(UT_sint32 xoff) ;
-	UT_sint32		    getMinOverline(void) ;
-	UT_sint32           getToplineThickness(void);
+	UT_sint32		    getMinOverline(void) const;
+	UT_sint32           getToplineThickness(void) const;
 
 	virtual UT_BidiCharType	getDirection() const { return m_iDirection; };
-	UT_BidiCharType		getVisDirection();
+	UT_BidiCharType		getVisDirection() const;
 	virtual void        setDirection(UT_BidiCharType iDirection = UT_BIDI_WS);
 	void				setVisDirection(UT_BidiCharType iDir);
-	UT_uint32           getVisPosition(UT_uint32 ilogPos);
-	UT_uint32           getVisPosition(UT_uint32 iLogPos, UT_uint32 iLen);
-	UT_uint32           getOffsetFirstVis();
-	UT_uint32           getOffsetLog(UT_uint32 iVisOff);
-	fp_Run *			getNextVisual();
-	fp_Run *			getPrevVisual();
+	UT_uint32           getVisPosition(UT_uint32 ilogPos) const;
+	UT_uint32           getVisPosition(UT_uint32 iLogPos, UT_uint32 iLen) const;
+	UT_uint32           getOffsetFirstVis() const;
+	UT_uint32           getOffsetLog(UT_uint32 iVisOff) const;
+	fp_Run *			getNextVisual(); // FIXME make const
+	fp_Run *			getPrevVisual(); // FIXME make const
 	UT_sint32           getAuthorNum(void) const
 	{ return m_iAuthorColor;};
 	void                setAuthorNum(UT_sint32 i)
@@ -303,7 +306,7 @@ public:
 	virtual void        adjustDeletePosition(UT_uint32 & /*pos1*/, 
 											 UT_uint32 & /*count*/) {}
 
-	bool                containsRevisions(){return (m_pRevisions != NULL);}
+	bool                containsRevisions() const {return (m_pRevisions != NULL);}
 	// would prefer to make the return value const, but the
 	// getLastRevision() and related functions use internal cache so
 	// they could not be called
@@ -314,7 +317,8 @@ public:
 	void                Fill(GR_Graphics * pG, UT_sint32 x, UT_sint32 y,
 							 UT_sint32 width, UT_sint32 height);
 	
-	fg_FillType *       getFillType(void);            
+	fg_FillType &       getFillType(void);
+	const fg_FillType & getFillType(void) const;
 	fp_Line *           getTmpLine(void) const
 	{ return m_pTmpLine;}
 	void                setTmpLine(fp_Line * pLine)
@@ -340,7 +344,8 @@ public:
 	// the users backs.
 	bool        deleteFollowingIfAtInsPoint() const;
 
-	bool        displayAnnotations(void);
+	bool        displayAnnotations(void) const;
+    bool        displayRDFAnchors(void) const;
 	// Methods for selection drawing
 	void                 setSelectionMode(PT_DocPosition posLow, PT_DocPosition posHigh);
     void                 clearSelectionMode(void);
@@ -736,9 +741,7 @@ class ABI_EXPORT fp_HyperlinkRun : public fp_Run
 public:
 	fp_HyperlinkRun(fl_BlockLayout* pBL, UT_uint32 iOffsetFirst, UT_uint32 iLen);
 	virtual ~fp_HyperlinkRun();
-	virtual FP_HYPERLINK_TYPE    getHyperlinkType(void)
-	{ return HYPERLINK_NORMAL;}
-
+	virtual FP_HYPERLINK_TYPE getHyperlinkType(void) const { return HYPERLINK_NORMAL;}
 	bool 				isStartOfHyperlink() const {return m_bIsStart;};
 	const gchar * 	getTarget() const {return static_cast<const gchar *>(m_pTarget);};
 
@@ -777,7 +780,9 @@ protected:
 	virtual bool _letPointPass(void) const;
 	virtual bool _canContainPoint(void) const;
 	virtual bool _deleteFollowingIfAtInsPoint() const;
-	
+    void _setTarget( const gchar * pTarget );
+	void _setTargetFromAPAttribute( const gchar* pAttrName );
+
 	bool m_bIsStart;
 	gchar *	  	m_pTarget;
 };
@@ -789,10 +794,7 @@ class ABI_EXPORT fp_AnnotationRun : public fp_HyperlinkRun
 public:
 	fp_AnnotationRun(fl_BlockLayout* pBL, UT_uint32 iOffsetFirst, UT_uint32 iLen);
 	virtual ~fp_AnnotationRun();
-	virtual FP_HYPERLINK_TYPE    getHyperlinkType(void)
-	{
-		return HYPERLINK_ANNOTATION;
-	}
+	virtual FP_HYPERLINK_TYPE getHyperlinkType(void) const { return HYPERLINK_ANNOTATION; }
 	UT_uint32 getPID(void) { return m_iPID;}
 	const char * getValue(void);
     void         recalcValue(void);
@@ -820,6 +822,41 @@ public:
 	UT_sint32               m_iRealWidth;
 };
 
+class ABI_EXPORT fp_RDFAnchorRun : public fp_HyperlinkRun
+{
+public:
+	fp_RDFAnchorRun(fl_BlockLayout* pBL, UT_uint32 iOffsetFirst, UT_uint32 iLen);
+	virtual ~fp_RDFAnchorRun();
+	virtual FP_HYPERLINK_TYPE getHyperlinkType(void) const { return HYPERLINK_RDFANCHOR; }
+	UT_uint32 getPID(void) { return m_iPID;}
+	const char * getValue(void);
+    void         recalcValue(void);
+	virtual bool canBreakAfter(void) const;
+	virtual bool canBreakBefore(void) const;
+	UT_sint32    getRealWidth(void) const {return m_iRealWidth;}
+    void         cleanDraw(dg_DrawArgs*);
+	UT_sint32    calcWidth(void);
+
+    std::string  getXMLID();
+
+ protected:
+	virtual void			_draw(dg_DrawArgs*);
+	virtual void			_clearScreen(bool bFullLineHeightRect);
+	virtual bool			_recalcWidth(void);
+	bool                    _setValue(void);
+	virtual void            _setWidth(UT_sint32 iWidth);
+	virtual bool _letPointPass(void) const;
+	virtual bool _canContainPoint(void) const;
+    virtual void _lookupProperties(const PP_AttrProp * pSpanAP,
+									const PP_AttrProp * pBlockAP,
+									const PP_AttrProp * pSectionAP,
+								   GR_Graphics * pG);
+ private:
+	UT_uint32               m_iPID;
+	UT_UTF8String           m_sValue;
+	UT_sint32               m_iRealWidth;
+};
+
 class ABI_EXPORT fp_ImageRun : public fp_Run
 {
 public:
