@@ -34,6 +34,7 @@
 #include "xap_Frame.h"
 #include "gr_Painter.h"
 #include "xap_App.h"
+#include "fv_ViewDoubleBuffering.h"
 
 FV_FrameEdit::FV_FrameEdit (FV_View * pView)
 	: FV_Base (pView), 
@@ -48,7 +49,10 @@ FV_FrameEdit::FV_FrameEdit (FV_View * pView)
 	  m_pFrameImage(NULL),
 	  m_pAutoScrollTimer(NULL),
 	  m_iInitialFrameX(0),
-	  m_iInitialFrameY(0)
+	  m_iInitialFrameY(0),
+	  m_sRelWidth(""),
+	  m_sMinHeight(""),
+	  m_sExpandHeight("")
 {
 	UT_ASSERT_HARMLESS(pView);
 }
@@ -269,6 +273,9 @@ UT_sint32 FV_FrameEdit::haveDragged(void) const
 
 void FV_FrameEdit::_mouseDrag(UT_sint32 x, UT_sint32 y)
 {
+	FV_ViewDoubleBuffering dblBuffObj(m_pView, false, false);
+	dblBuffObj.beginDoubleBuffering();
+	
 	UT_sint32 dx = 0;
 	UT_sint32 dy = 0;
 	UT_Rect expX(0,m_recCurFrame.top,0,m_recCurFrame.height);
@@ -390,60 +397,43 @@ void FV_FrameEdit::_mouseDrag(UT_sint32 x, UT_sint32 y)
 	{
 		xxx_UT_DEBUGMSG(("width after drag %d \n",m_recCurFrame.width));
 	}
-	else if (FV_FrameEdit_RESIZE_EXISTING == m_iFrameEditMode)
+	else 
 	{
-		UT_sint32 iW = m_recCurFrame.width;
-		UT_sint32 iH = m_recCurFrame.height;
-		UT_sint32 newX = m_pFrameContainer->getFullX();
-		UT_sint32 newY = m_pFrameContainer->getFullY();
-		m_pFrameLayout->localCollapse();
-		m_pFrameLayout->setFrameWidth(iW);
-		m_pFrameLayout->setFrameHeight(iH);
-		m_pFrameContainer->_setWidth(iW);
-		m_pFrameContainer->_setHeight(iH);
-		m_pFrameLayout->miniFormat();
-		m_pFrameLayout->getDocSectionLayout()->setNeedsSectionBreak(false,NULL);
-		newX += dx;
-		newY += dy;
-		m_pFrameContainer->_setX(newX);
-		m_pFrameContainer->_setY(newY);
-		if(expX.width > 0)
+		if (FV_FrameEdit_RESIZE_EXISTING == m_iFrameEditMode)
 		{
-			getGraphics()->setClipRect(&expX);
-			m_pView->updateScreen(false);
+			UT_sint32 iW = m_recCurFrame.width;
+			UT_sint32 iH = m_recCurFrame.height;
+			m_pFrameLayout->localCollapse();
+			m_pFrameLayout->setFrameWidth(iW);
+			m_pFrameLayout->setFrameHeight(iH);
+			m_pFrameContainer->_setWidth(iW);
+			m_pFrameContainer->_setHeight(iH);
+			m_pFrameLayout->miniFormat();
+			m_pFrameLayout->getDocSectionLayout()->setNeedsSectionBreak(false,NULL);
 		}
-		if(expY.height > 0)
-		{
-			getGraphics()->setClipRect(&expY);
-			xxx_UT_DEBUGMSG(("expY.top %d expY.height %d \n",expY.top,expY.height));
-			m_pView->updateScreen(false);
-		}
-		getGraphics()->setClipRect(NULL);
 
-		drawFrame(true);
-		xxx_UT_DEBUGMSG(("Draw frame finished \n"));
-	}
-	else if (FV_FrameEdit_DRAG_EXISTING == m_iFrameEditMode)
-	{
-		UT_sint32 newX = m_pFrameContainer->getFullX();
-		UT_sint32 newY = m_pFrameContainer->getFullY();
-		newX += dx;
-		newY += dy;
-		m_pFrameContainer->_setX(newX);
-		m_pFrameContainer->_setY(newY);
-		xxx_UT_DEBUGMSG(("Doing dragging existing frame left %d top %d \n",m_recCurFrame.left, m_recCurFrame.top));
-		if(expX.width > 0)
+		if (FV_FrameEdit_RESIZE_EXISTING == m_iFrameEditMode || FV_FrameEdit_DRAG_EXISTING == m_iFrameEditMode)
 		{
-			getGraphics()->setClipRect(&expX);
-			m_pView->updateScreen(false);
+			UT_sint32 newX = m_pFrameContainer->getFullX();
+			UT_sint32 newY = m_pFrameContainer->getFullY();
+			newX += dx;
+			newY += dy;
+			m_pFrameContainer->_setX(newX);
+			m_pFrameContainer->_setY(newY);
+			if(expX.width > 0)
+			{
+				getGraphics()->setClipRect(&expX);
+				m_pView->updateScreen(false);
+			}
+			if(expY.height > 0)
+			{
+				getGraphics()->setClipRect(&expY);
+				m_pView->updateScreen(false);
+			}
+			getGraphics()->setClipRect(NULL);
+			
+			drawFrame(true);
 		}
-		if(expY.height > 0)
-		{
-			getGraphics()->setClipRect(&expY);
-			m_pView->updateScreen(false);
-		}
-		getGraphics()->setClipRect(NULL);
-		drawFrame(true);
 	}
 	m_iLastX = x;
 	m_iLastY = y;
@@ -654,6 +644,29 @@ void FV_FrameEdit::setDragType(UT_sint32 x, UT_sint32 y, bool bDrawFrame)
 	{
 		drawFrame(true);
 	}
+	const PP_AttrProp * pAP = NULL;
+	pFL->getAP(pAP);
+	const char * pszPercentWidth = NULL;
+	const char * pszMinHeight = NULL;
+	const char * pszExpandHeight = NULL;
+	if(pAP && pAP->getProperty("frame-rel-width",pszPercentWidth))
+	{
+		if(pszPercentWidth)
+		{
+		     m_sRelWidth = pszPercentWidth;
+		}
+	}
+	if(pAP && pAP->getProperty("frame-min-height",pszMinHeight))
+	{
+		if(pszMinHeight)
+		{
+		     m_sMinHeight = pszMinHeight;
+		}
+	}
+	if(pAP && pAP->getProperty("frame-expand-height",pszExpandHeight))
+	{
+	        m_sExpandHeight = pszExpandHeight;
+	}	
 	m_recCurFrame.left = iLeft;
 	m_recCurFrame.top = iTop;
 	m_recCurFrame.width = (iRight - iLeft);
@@ -662,6 +675,7 @@ void FV_FrameEdit::setDragType(UT_sint32 x, UT_sint32 y, bool bDrawFrame)
 	m_iLastY = y;
 	m_iInitialDragX = iLeft;
 	m_iInitialDragY = iTop;
+	
 	xxx_UT_DEBUGMSG(("Initial width %d \n",m_recCurFrame.width));
 	xxx_UT_DEBUGMSG((" Dragging What %d \n",getDragWhat()));
 	m_pView->setCursorToContext();
@@ -899,8 +913,16 @@ bool FV_FrameEdit::getFrameStrings(UT_sint32 x, UT_sint32 y,
 		UT_sint32 iColx = 0;
 		UT_sint32 iColy = 0;
 		fp_Page * pPage = pCol->getPage();
-		pPage->getScreenOffsets(pCol,iColx,iColy);
-		UT_sint32 xp,yp;
+		if(!pPage)
+		{
+		    return false;
+		}
+		else
+		{
+		    pPage->getScreenOffsets(pCol,iColx,iColy);
+		}
+		UT_sint32 xp=0;
+		UT_sint32 yp= 0;
 		m_pView->getPageScreenOffsets(pPage,xp,yp);
 		UT_sint32 finalColx = x - iColx;
 		if(finalColx + iColx - xp < 0)
@@ -910,7 +932,10 @@ bool FV_FrameEdit::getFrameStrings(UT_sint32 x, UT_sint32 y,
 		else if(finalColx + iColx + m_recCurFrame.width - xp > pPage->getWidth())
 		{
 		  //			x -= finalColx + iColx + m_recCurFrame.width -xp - pPage->getWidth();
-		  x = pPage->getWidth() - m_recCurFrame.width;
+		  if(pPage)
+		  {
+		      x = pPage->getWidth() - m_recCurFrame.width;
+		  }
 		}
 		finalColx = x - iColx;
 
@@ -994,6 +1019,10 @@ bool FV_FrameEdit::getFrameStrings(UT_sint32 x, UT_sint32 y,
 //
 void FV_FrameEdit::abortDrag(void)
 {
+  FV_ViewDoubleBuffering dblBuffObj(m_pView, true, true);
+  dblBuffObj.beginDoubleBuffering();
+
+
   UT_DEBUGMSG(("Doing Abort Drag \n"));
   m_xLastMouse = m_iFirstEverX;
   m_yLastMouse = m_iFirstEverY;
@@ -1006,6 +1035,10 @@ void FV_FrameEdit::mouseRelease(UT_sint32 x, UT_sint32 y)
 //
 // If we've just selected the frame, ignore this event.
 //
+
+	FV_ViewDoubleBuffering dblBuffObj(m_pView, true, true);
+	dblBuffObj.beginDoubleBuffering();
+
 	UT_DEBUGMSG(("Doing mouse release now! Mode %d \n", getFrameEditMode()));
 	if(FV_FrameEdit_EXISTING_SELECTED == m_iFrameEditMode)
 	{
@@ -1047,7 +1080,7 @@ void FV_FrameEdit::mouseRelease(UT_sint32 x, UT_sint32 y)
 		//				 Recommend to do whatever is done for thickness, which must also have a default set but not
 		//				 reverted to on every change.
 		// TODO: if(pAP->getProperty("*-thickness", somePropHolder)) sLeftThickness = gchar_strdup(somePropHolder); else sLeftThickness = "1px";
-		const gchar * props[40] = {"frame-type","textbox",
+		const gchar * props[46] = {"frame-type","textbox",
 					      "wrap-mode","wrapped-both",
 					      "position-to","column-above-text",
 					      "xpos",sXpos.c_str(),
@@ -1065,7 +1098,10 @@ void FV_FrameEdit::mouseRelease(UT_sint32 x, UT_sint32 y)
 						  "top-style","1",
 						  "bot-style","1",
 						  "bg-style","1",
-					      "tight-wrap","0",
+					   "tight-wrap","0",
+					   "frame-rel-width",m_sRelWidth.c_str(),
+					   "frame-min-height",m_sMinHeight.c_str(),
+					   "frame-expand-height",m_sExpandHeight.c_str(),
 					      NULL,NULL};
 //
 // This should place the the frame strux immediately after the block containing
@@ -1485,7 +1521,17 @@ void FV_FrameEdit::mouseRelease(UT_sint32 x, UT_sint32 y)
 		UT_String_setProperty(sFrameProps,sProp,sVal);		
 		sProp = "pref-page";
 		sVal = sPrefPage;
-		UT_String_setProperty(sFrameProps,sProp,sVal);		
+		UT_String_setProperty(sFrameProps,sProp,sVal);
+
+		sProp = "frame-rel-width";
+		sVal = m_sRelWidth;
+		UT_String_setProperty(sFrameProps,sProp,sVal);
+		sProp = "frame-min-height";
+		sVal = m_sMinHeight;
+		UT_String_setProperty(sFrameProps,sProp,sVal);
+		sProp = "frame-expand-height";
+		sVal = m_sExpandHeight;
+		UT_String_setProperty(sFrameProps,sProp,sVal);
 		//
 		// Get all the blocks around the frame
 		//
@@ -1746,6 +1792,10 @@ void FV_FrameEdit::deleteFrame(fl_FrameLayout * pFL)
 		  return;
 		}
 	}
+
+	FV_ViewDoubleBuffering dblBuffObj(m_pView, true, true);
+	dblBuffObj.beginDoubleBuffering();
+
 	PP_AttrProp * p_AttrProp_Before = NULL;
 
 	// Signal PieceTable Change
@@ -1860,7 +1910,8 @@ void FV_FrameEdit::drawFrame(bool bWithHandles)
 	}
 	else
 	{
-		GR_Painter painter (getGraphics());
+		GR_Painter painter(getGraphics());
+		m_pView->draw(&m_recCurFrame);
 		painter.drawImage(m_pFrameImage,m_recCurFrame.left,m_recCurFrame.top);
 	}
 }
