@@ -63,6 +63,7 @@ class UT_UTF8String;
 class pp_Author;
 class PD_DocumentRDF;
 class AP_StatusBar;
+class PL_ListenerCoupleCloser;
 
 #include <boost/shared_ptr.hpp>
 typedef boost::shared_ptr<PD_DocumentRDF> PD_DocumentRDFHandle;
@@ -200,6 +201,27 @@ private:
 	UT_ByteBuf m_sContent;
 };
 
+class PD_XMLIDCreatorPrivate;
+
+class ABI_EXPORT PD_XMLIDCreator
+{
+    friend class PD_Document;
+    PD_Document* m_doc;
+    PD_XMLIDCreatorPrivate* m_impl;
+    
+  protected:
+
+    PD_XMLIDCreator( PD_Document* doc );
+    void rebuildCache();
+    
+  public:
+    
+    ~PD_XMLIDCreator();
+    std::string createUniqueXMLID( const std::string& desiredID, bool deepCopyRDF = false );
+};
+typedef boost::shared_ptr<PD_XMLIDCreator> PD_XMLIDCreatorHandle;
+
+
 
 /*!
  PD_Document is the representation for a document.
@@ -391,8 +413,9 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool                    repairDoc(void);
 	bool                    removeStyle(const gchar * name);
 	bool					tellListener(PL_Listener * pListener);
-	bool					tellListenerSubset(PL_Listener * pListener,
-											   PD_DocumentRange * pDocRange);
+	bool					tellListenerSubset( PL_Listener * pListener,
+                                                PD_DocumentRange * pDocRange,
+                                                PL_ListenerCoupleCloser* closer = 0 );
 	bool					addListener(PL_Listener * pListener, PL_ListenerId * pListenerId);
 	bool					removeListener(PL_ListenerId listenerId);
 	bool					signalListeners(UT_uint32 iSignal) const;
@@ -433,6 +456,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 													   PTStruxType pts,
 													   PL_StruxFmtHandle * psfh) const;
 	bool					getStruxOfTypeFromPosition(PT_DocPosition, PTStruxType pts, PL_StruxDocHandle * sdh) const;
+    PL_StruxDocHandle       getBlockFromPosition( PT_DocPosition pos ) const;
 
 	pf_Frag *				getFragFromPosition(PT_DocPosition docPos) const;
 
@@ -484,6 +508,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	// styles
 	void                    getAllUsedStyles(UT_GenericVector<PD_Style*> * pVecStyles);
 	PL_StruxFmtHandle       getNthFmtHandle(PL_StruxDocHandle sdh, UT_uint32 n);
+    const char *            getDefaultStyle() const;
 	bool					getStyle(const char * szName, PD_Style ** ppStyle) const;
 	PD_Style *				getStyleFromSDH(PL_StruxDocHandle sdh);
 	PL_StruxDocHandle       getPrevNumberedHeadingStyle(PL_StruxDocHandle sdh);
@@ -548,6 +573,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 												 UT_sint32 row, 
 												 UT_sint32 col);
 	void                    miniDump(PL_StruxDocHandle sdh, UT_sint32 nstruxes);
+    bool                    dumpDoc( const char* msg, PT_DocPosition currentpos, PT_DocPosition endpos );
 
 	bool                    isInsertHyperLinkValid(PT_DocPosition pos) const;
 
@@ -618,6 +644,8 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	pt_PieceTable *			getPieceTable(void) const
 		{ return m_pPieceTable; }
     PD_DocumentRDFHandle    getDocumentRDF(void) const;
+    PD_XMLIDCreatorHandle   makeXMLIDCreator();
+    
 #ifdef PT_TEST
 	void					__dump(FILE * fp) const;
 	//! Pointer to last instatiated PD_Document. Used for debugging.
