@@ -75,8 +75,13 @@ static PP_Property _props[] =
 {
 	{ "background-color",      "transparent",     false, NULL, PP_LEVEL_SECT},
 	{ "bgcolor",               "transparent",     true,  NULL, PP_LEVEL_CHAR},
+	{"border-merge",           "0",               true,  NULL, PP_LEVEL_BLOCK},
+	{"border-shadow-merge",    "0",               true,  NULL, PP_LEVEL_BLOCK},
 	{ "bot-attach",            "",               false,  NULL, PP_LEVEL_TABLE},
 	{ "bot-color",             "000000",          false, NULL, PP_LEVEL_TABLE},
+	{ "bot-shadow",            "0",               false, NULL, PP_LEVEL_BLOCK},
+	{ "bot-shadow-color",      "grey",            false, NULL, PP_LEVEL_BLOCK},
+	{ "bot-space",             "0.02in",          false, NULL, PP_LEVEL_BLOCK},
 	{ "bot-style",             "1",           false, NULL, PP_LEVEL_TABLE},
 	{ "bot-thickness",         "1px",             false, NULL, PP_LEVEL_TABLE},
 
@@ -135,8 +140,12 @@ static PP_Property _props[] =
 	{ "lang",                  "en-US",           true,  NULL, PP_LEVEL_CHAR},
 	{ "left-attach",           "",               false,  NULL, PP_LEVEL_TABLE},
 	{ "left-color",            "000000",          false, NULL, PP_LEVEL_TABLE},
+	{ "left-shadow",           "0",               false, NULL, PP_LEVEL_BLOCK},
+	{ "left-shadow-color",     "grey",            false, NULL, PP_LEVEL_BLOCK},
+	{ "left-space",            "0.02in",          false, NULL, PP_LEVEL_BLOCK},
 	{ "left-style",            "1",           false, NULL, PP_LEVEL_TABLE},
 	{ "left-thickness",        "1px",             false, NULL, PP_LEVEL_TABLE},
+
 	{ "line-height",           "1.0",             false, NULL, PP_LEVEL_BLOCK},
 	{ "list-decimal",          ".",               true,  NULL, PP_LEVEL_BLOCK},
 	{ "list-delim",            "%L",              true,  NULL, PP_LEVEL_BLOCK},
@@ -159,6 +168,9 @@ static PP_Property _props[] =
 
 	{ "right-attach",         "",               false,  NULL, PP_LEVEL_TABLE},
 	{ "right-color",           "000000",          false, NULL, PP_LEVEL_TABLE},
+	{ "right-shadow",          "0",               false, NULL, PP_LEVEL_BLOCK},
+	{ "right-shadow-color",    "grey",            false, NULL, PP_LEVEL_BLOCK},
+	{ "right-space",           "0.02in",          false, NULL, PP_LEVEL_BLOCK},
 	{ "right-style",           "1",           false, NULL, PP_LEVEL_TABLE},
 	{ "right-thickness",       "1px",             false, NULL, PP_LEVEL_TABLE},
 
@@ -168,6 +180,9 @@ static PP_Property _props[] =
 	{ "section-restart",       "",                false, NULL, PP_LEVEL_SECT},
 	{ "section-restart-value", "",                false, NULL, PP_LEVEL_SECT},
 	{ "section-space-after",   "0.25in",          false, NULL, PP_LEVEL_SECT},
+	{"shading-background-color", "white",         false,NULL, PP_LEVEL_BLOCK},
+	{"shading-foreground-color", "white",         false,NULL, PP_LEVEL_BLOCK},
+	{"shading-pattern",          "0",             false,NULL, PP_LEVEL_BLOCK},
 	{ "start-value",           "1",               true,  NULL, PP_LEVEL_BLOCK},
 
 	{ "table-border",          "0.1in",           false, NULL, PP_LEVEL_TABLE},
@@ -242,9 +257,15 @@ static PP_Property _props[] =
 
 	{ "top-attach",             "",               false, NULL, PP_LEVEL_TABLE},
 	{ "top-color",             "000000",          false, NULL, PP_LEVEL_TABLE},
-	{ "top-style",             "1",           false, NULL, PP_LEVEL_TABLE},
+	{ "top-shadow",            "0",               false, NULL, PP_LEVEL_BLOCK},
+	{ "top-shadow-color",      "grey",            false, NULL, PP_LEVEL_BLOCK},
+	{ "top-space",             "0.02in",          false, NULL, PP_LEVEL_BLOCK},
+	{ "top-style",             "1",               false, NULL, PP_LEVEL_TABLE},
 	{ "top-thickness",         "1px",             false, NULL, PP_LEVEL_TABLE},
 
+
+	{ "vert-align",            "0",               false, NULL, PP_LEVEL_TABLE},
+
 	{ "widows",                "2",               false, NULL, PP_LEVEL_BLOCK},
 	{ "width",                 "0in",             false, NULL, PP_LEVEL_CHAR}, 
 	{ "wrap-mode",             "above-text",      false, NULL, PP_LEVEL_FRAME} 
