@@ -54,10 +54,15 @@ public:
 		abi_background_color,
 		abi_background_image,
 		abi_bgcolor,
+		abi_border_merge,
+		abi_border_shadow_merge,
 		abi_bot_attach,
 		abi_bot_color,
 		abi_bot_style,
 		abi_bot_thickness,
+		abi_bot_shadow,
+		abi_bot_shadow_color,
+		abi_bot_space,
 		abi_bounding_space,
 		abi_cell_margin_bottom,
 		abi_cell_margin_left,
@@ -120,6 +125,9 @@ public:
 		abi_left_color,
 		abi_left_style,
 		abi_left_thickness,
+		abi_left_shadow,
+		abi_left_shadow_color,
+		abi_left_space,
 		abi_line_height,
 		abi_list_decimal,
 		abi_list_delim,
@@ -141,12 +149,18 @@ public:
 		abi_right_color,
 		abi_right_style,
 		abi_right_thickness,
+		abi_right_shadow,
+		abi_right_shadow_color,
+		abi_right_space,
 		abi_section_footnote_line_thickness,
 		abi_section_footnote_yoff,
 		abi_section_max_column_height,
 		abi_section_restart,
 		abi_section_restart_value,
 		abi_section_space_after,
+		abi_shading_background_color,
+		abi_shading_foreground_color,
+		abi_shading_pattern,
 		abi_start_value,
 		abi_table_border,
 		abi_table_col_spacing,
@@ -224,6 +238,10 @@ public:
 		abi_top_color,
 		abi_top_style,
 		abi_top_thickness,
+		abi_top_shadow,
+		abi_top_shadow_color,
+		abi_top_space,
+		abi_vert_align,
 		abi_widows,
 		abi_width,
 		abi_wrap_mode,
@@ -282,14 +300,16 @@ public:
 		Line ();
 
 		void reset (); // restore defaults
-
 		TypeColor		m_t_color;
 		TypeLineStyle	m_t_linestyle;
 		TypeThickness	m_t_thickness;
 
 		UT_RGBColor		m_color;		// in case of color_color
 		UT_uint32		m_thickness;	// in case of thickness_length
+		UT_sint32       m_spacing;      // gap in logical unit to content
 	};
+
+
 	class ABI_EXPORT Background
 	{
 	public:
@@ -305,6 +325,7 @@ public:
 	static const char * abi_property_name (AbiPropertyIndex index);
 
 	static bool abi_property_lookup (const char * name, AbiPropertyIndex & index);
+
 #if 0
 	typedef std::map<UT_sint32, UT_UTF8String *> map_type;
 private:
@@ -375,5 +396,6 @@ public:
 	}
 #endif
 };
+ABI_EXPORT bool operator==(const PP_PropertyMap::Line L1, const PP_PropertyMap::Line L2);
 
 #endif /* ! PP_PROPERTYMAP_H */
