@@ -42,6 +42,7 @@ class pf_Frag_Strux_Block;
 class pf_Frag_Strux_Section;
 class PX_ChangeRecord_Span;
 class PD_Style;
+class PL_ListenerCoupleCloser;
 
 #ifdef PT_TEST
 #include "ut_test.h"
@@ -146,6 +147,8 @@ protected:
 	
     bool                    _realChangeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
 
+
+    
 	/******************************************************************
 	    these are the new revisions aware methods
 	*/
@@ -165,6 +168,16 @@ public:
 									   UT_uint32 length, fd_Field * pField = NULL,
 									   bool bAddChangeRec = true);
 
+    pf_Frag* getEndOfBlock( PT_DocPosition currentpos, PT_DocPosition endpos );
+    // bool deleteSpanChangeTrackingAreWeMarkingDeltaMerge( PT_DocPosition startpos,
+    //                                                      PT_DocPosition endpos );
+    pf_Frag_Strux* inSameBlock( PT_DocPosition startpos, PT_DocPosition endpos );
+    // bool changeTrackingAddParaAttribute( pf_Frag_Strux* pfs,
+    //                                      const char* attr,
+    //                                      std::string v );
+    // bool deleteSpanChangeTrackingMaybeMarkParagraphEndDeletion( PT_DocPosition currentpos,
+    //                                                             PT_DocPosition endpos );
+    
 	bool					deleteSpan(PT_DocPosition dpos1,
 									   PT_DocPosition dpos2,
 									   PP_AttrProp *p_AttrProp_Before,
@@ -282,8 +295,9 @@ public:
 	size_t					getStyleCount(void) const;
 
 	bool					tellListener(PL_Listener * pListener);
-	bool					tellListenerSubset(PL_Listener * pListener,
-											   PD_DocumentRange * pDocRange);
+	bool					tellListenerSubset( PL_Listener * pListener,
+											    PD_DocumentRange * pDocRange,
+                                                PL_ListenerCoupleCloser* closer = 0 );
 
 	bool					addListener(PL_Listener * pListener,
 										PL_ListenerId listenerId);
@@ -304,10 +318,13 @@ public:
 
 	bool					getBlockBuf(PL_StruxDocHandle sdh, UT_GrowBuf * pgb) const;
 
+    PT_DocPosition          getPosEnd();
 	bool					getBounds(bool bEnd, PT_DocPosition & docPos) const;
 	PT_DocPosition			getStruxPosition(PL_StruxDocHandle sdh) const;
 	PT_DocPosition			getFragPosition(const pf_Frag * pfToFind) const;
 
+    bool dumpDoc( const char* msg, PT_DocPosition currentpos, PT_DocPosition endpos );
+    
 	bool					getFragFromPosition(PT_DocPosition docPos,
 												pf_Frag ** ppf,
 												PT_BlockOffset * pOffset) const;
@@ -317,6 +334,7 @@ public:
 													   PTStruxType pts,
 													   PL_StruxFmtHandle * psfh) const;
 
+    PL_StruxDocHandle       getBlockFromPosition(PT_DocPosition pos) const;
 
 	bool					getStruxOfTypeFromPosition(PT_DocPosition docPos,
 													   PTStruxType pts,
@@ -367,7 +385,11 @@ public:
 
 protected:
 
-	pf_Frag *               _findLastStruxOfType(pf_Frag * pfStart, PTStruxType pst, bool bSkipEmbeded);
+    pf_Frag_Strux*          _findLastStruxOfType(pf_Frag * pfStart,
+                                                 PTStruxType pst,
+                                                 PTStruxType* stopConditions,
+                                                 bool bSkipEmbededSections );
+    pf_Frag_Strux*          _findLastStruxOfType(pf_Frag * pfStart, PTStruxType pst, bool bSkipEmbeded);
 	pf_Frag *               _findPrevHyperlink(pf_Frag * pfStart);
 	pf_Frag *               _findNextHyperlink(pf_Frag * pfStart);
 
@@ -414,7 +436,8 @@ protected:
 	bool					_getStruxOfTypeFromPosition(PT_DocPosition dpos,
 														PTStruxType pts,
 														pf_Frag_Strux ** ppfs) const;
-	bool					_doTheDo(const PX_ChangeRecord * pcr, bool bUndo);
+    pf_Frag_Strux*          _getBlockFromPosition(PT_DocPosition pos) const;
+    bool					_doTheDo(const PX_ChangeRecord * pcr, bool bUndo);
 	bool					_struxHasContent(pf_Frag_Strux * pfs) const;
 	bool					_struxIsEmpty(pf_Frag_Strux * pfs) const;
 	bool					_unlinkStrux(pf_Frag_Strux * pfs,
@@ -446,6 +469,17 @@ protected:
 	bool					_deleteFormatting(PT_DocPosition dpos1,
 											  PT_DocPosition dpos2);
 
+    bool                     _deleteComplexSpanHAR( pf_Frag_Object *pO,
+                                                    PT_DocPosition dpos1,
+                                                    PT_DocPosition dpos2,
+                                                    UT_uint32& length,
+                                                    PT_BlockOffset& fragOffset_First,
+                                                    UT_uint32& lengthThisStep,
+                                                    pf_Frag_Strux*& pfsContainer,
+                                                    pf_Frag*& pfNewEnd,
+                                                    UT_uint32& fragOffsetNewEnd,
+                                                    const char* startAttrCSTR );
+
 	bool					_deleteComplexSpan(PT_DocPosition & dpos1,
 											   PT_DocPosition & dpos2,
 											   UT_Stack *stDelayStruxDelete);
