@@ -172,4 +172,13 @@ typedef const void * PL_StruxFmtHandle;
 #define PT_RDF_XMLID             (static_cast<const gchar *>("xml:id"))
 #define PT_XMLID                 (static_cast<const gchar *>("xml:id"))
 #define PT_RDF_END               (static_cast<const gchar *>("rdf:end"))
+#define PT_CHANGETRACKING_SPLIT_ID     (static_cast<const gchar *>("ct:split-id"))
+#define PT_CHANGETRACKING_SPLIT_ID_REF (static_cast<const gchar *>("ct:split-id-ref"))
+#define PT_CHANGETRACKING_SPLIT_IS_NEW (static_cast<const gchar *>("ct:split-is-new"))
+
+
+#define ABIATTR_PARA_START_DELETED_REVISION (static_cast<const gchar *>("abi-para-start-deleted-revision"))
+#define ABIATTR_PARA_END_DELETED_REVISION   (static_cast<const gchar *>("abi-para-end-deleted-revision"))
+#define ABIATTR_PARA_DELETED_REVISION   (static_cast<const gchar *>("abi-para-deleted-revision"))
+
 #endif /* PT_TYPES_H */
