@@ -82,7 +82,7 @@ void AP_CocoaFrameImpl::_setHScrollValue(UT_sint32 value)
 		if (m_HCurrentScroll > m_HMaxScroll) {
 			m_HCurrentScroll = m_HMaxScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setHScrollValue : %d\n", value));
+		UT_DEBUGMSG(("_setHScrollValue : %d\n", value));
 		_setHScrollbarValues();
 	}
 }
@@ -94,7 +94,7 @@ void AP_CocoaFrameImpl::_setHScrollMin(UT_sint32 value)
 		if (m_HCurrentScroll < m_HMinScroll) {
 			m_HCurrentScroll = m_HMinScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setHScrollMin : %d\n", value));
+		UT_DEBUGMSG(("_setHScrollMin : %d\n", value));
 		_setHScrollbarValues();
 	}
 }
@@ -106,7 +106,7 @@ void AP_CocoaFrameImpl::_setHScrollMax(UT_sint32 value)
 		if (m_HCurrentScroll > m_HMaxScroll) {
 			m_HCurrentScroll = m_HMaxScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setHScrollMax : %d\n", value));
+		UT_DEBUGMSG(("_setHScrollMax : %d\n", value));
 		_setHScrollbarValues();
 	}
 }
@@ -129,7 +129,7 @@ void AP_CocoaFrameImpl::_setVScrollValue(UT_sint32 value)
 		if (m_VCurrentScroll > m_VMaxScroll) {
 			m_VCurrentScroll = m_VMaxScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setVScrollValue : %d\n", value));
+		UT_DEBUGMSG(("_setVScrollValue : %d\n", value));
 		_setVScrollbarValues();
 	}
 }
@@ -141,7 +141,7 @@ void AP_CocoaFrameImpl::_setVScrollMin(UT_sint32 value)
 		if (m_VCurrentScroll < m_VMinScroll) {
 			m_VCurrentScroll = m_VMinScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setVScrollMin : %d\n", value));
+		UT_DEBUGMSG(("_setVScrollMin : %d\n", value));
 		_setVScrollbarValues();
 	}
 }
@@ -153,7 +153,7 @@ void AP_CocoaFrameImpl::_setVScrollMax(UT_sint32 value)
 		if (m_VCurrentScroll > m_VMaxScroll) {
 			m_VCurrentScroll = m_VMaxScroll;
 		}
-		xxx_UT_DEBUGMSG(("_setVScrollMax : %d\n", value));
+		UT_DEBUGMSG(("_setVScrollMax : %d\n", value));
 		_setVScrollbarValues();
 	}
 }
@@ -168,7 +168,8 @@ void AP_CocoaFrameImpl::_setVVisible(UT_sint32 value)
 
 void AP_CocoaFrameImpl::_setHScrollbarValues()
 {
-	float value, knob;
+	float value;
+	CGFloat knob;
 	if (m_HMaxScroll == 0) {
 		value = 0.0;
 	}
@@ -179,16 +180,17 @@ void AP_CocoaFrameImpl::_setHScrollbarValues()
 		knob = 1.0;
 	}
 	else {
-		knob = ((float)m_HVisible / (float)(m_HVisible + m_HMaxScroll));
+		knob = ((CGFloat)m_HVisible / (CGFloat)(m_HVisible + m_HMaxScroll));
 	}
-	xxx_UT_DEBUGMSG(("_setHScrollbarValues(), max = %d, current = %d, visible = %d\n", m_HMaxScroll, m_HCurrentScroll, m_HVisible));
-	xxx_UT_DEBUGMSG(("_setHScrollbarValues(), value = %f, knob = %f\n", value, knob));
+	UT_DEBUGMSG(("_setHScrollbarValues(), max = %d, current = %d, visible = %d\n", m_HMaxScroll, m_HCurrentScroll, m_HVisible));
+	UT_DEBUGMSG(("_setHScrollbarValues(), value = %f, knob = %f\n", value, knob));
 	if (knob >= 1.0) {
 		[m_hScrollbar setEnabled:NO];
 	}
 	else {
 		[m_hScrollbar setEnabled:YES];
-		[m_hScrollbar setFloatValue:value knobProportion:knob];
+		[m_hScrollbar setKnobProportion:knob];
+		[m_hScrollbar setDoubleValue:value];
 	}
 	[m_hScrollbar setNeedsDisplay:YES];
 	[[(AP_CocoaFrameController*)_getController() getHRuler] setNeedsDisplay:YES];
@@ -197,7 +199,8 @@ void AP_CocoaFrameImpl::_setHScrollbarValues()
 
 void AP_CocoaFrameImpl::_setVScrollbarValues()
 {
-	float value, knob;
+	float value;
+	CGFloat knob;
 	if (m_VMaxScroll == 0) {
 		value = 0.0;
 	}
@@ -208,16 +211,17 @@ void AP_CocoaFrameImpl::_setVScrollbarValues()
 		knob = 1.0;
 	}
 	else {
-		knob = ((float)m_VVisible / (float)(m_VVisible + m_VMaxScroll));
+		knob = ((CGFloat)m_VVisible / (CGFloat)(m_VVisible + m_VMaxScroll));
 	}
-	xxx_UT_DEBUGMSG(("_setVScrollbarValues(), max = %d, current = %d, visible = %d\n", m_VMaxScroll, m_VCurrentScroll, m_VVisible));
-	xxx_UT_DEBUGMSG(("_setVScrollbarValues(), value = %f, knob = %f\n", value, knob));
+	UT_DEBUGMSG(("_setVScrollbarValues(), max = %d, current = %d, visible = %d\n", m_VMaxScroll, m_VCurrentScroll, m_VVisible));
+	UT_DEBUGMSG(("_setVScrollbarValues(), value = %f, knob = %f\n", value, knob));
 	if (knob >= 1.0) {
 		[m_vScrollbar setEnabled:NO];
 	}
 	else {
 		[m_vScrollbar setEnabled:YES];
-		[m_vScrollbar setFloatValue:value knobProportion:knob];
+		[m_vScrollbar setKnobProportion:knob];
+		[m_vScrollbar setDoubleValue:value];
 	}
 	[m_vScrollbar setNeedsDisplay:YES];
 	// [[(_getController()) getVRuler] setNeedsDisplay:YES]; // ??
@@ -231,14 +235,14 @@ void AP_CocoaFrameImpl::_scrollAction(id sender)
 	AV_View * pView = getFrame()->getCurrentView();
 	GR_Graphics * pGr = pView->getGraphics();
 
-	xxx_UT_DEBUGMSG(("newValue = %f\n", newValue));
+	UT_DEBUGMSG(("newValue = %f\n", newValue));
 	switch (part) {
 	case NSScrollerNoPart:
-		xxx_UT_DEBUGMSG(("No Scroll\n"));
+		UT_DEBUGMSG(("No Scroll\n"));
 		return;
 		break;
     case NSScrollerDecrementPage:
-		xxx_UT_DEBUGMSG(("NSScrollerDecrementPage\n"));
+		UT_DEBUGMSG(("NSScrollerDecrementPage\n"));
 		if (sender == m_vScrollbar) {
 			_setVScrollValue(m_VCurrentScroll - m_VVisible);
 		}
@@ -247,7 +251,7 @@ void AP_CocoaFrameImpl::_scrollAction(id sender)
 		}
 		break;
     case NSScrollerIncrementPage:
-		xxx_UT_DEBUGMSG(("NSScrollerIncrementPage\n"));
+		UT_DEBUGMSG(("NSScrollerIncrementPage\n"));
 		if (sender == m_vScrollbar) {
 			_setVScrollValue(m_VCurrentScroll + m_VVisible);
 		}
@@ -256,7 +260,7 @@ void AP_CocoaFrameImpl::_scrollAction(id sender)
 		}
 		break;
     case NSScrollerDecrementLine:
-		xxx_UT_DEBUGMSG(("NSScrollerDecrementLine\n"));
+		UT_DEBUGMSG(("NSScrollerDecrementLine\n"));
 		if (sender == m_vScrollbar) {
 			_setVScrollValue(m_VCurrentScroll - pGr->tlu(20));
 		}
@@ -265,7 +269,7 @@ void AP_CocoaFrameImpl::_scrollAction(id sender)
 		}
 		break;
     case NSScrollerIncrementLine:
-		xxx_UT_DEBUGMSG(("NSScrollerIncrementLine\n"));
+		UT_DEBUGMSG(("NSScrollerIncrementLine\n"));
 		if (sender == m_vScrollbar) {
 			_setVScrollValue(m_VCurrentScroll + pGr->tlu(20));
 		}
@@ -275,7 +279,7 @@ void AP_CocoaFrameImpl::_scrollAction(id sender)
 		break;
     case NSScrollerKnob	:
     case NSScrollerKnobSlot	:
-		xxx_UT_DEBUGMSG(("NSScrollerKnob\n"));
+		UT_DEBUGMSG(("NSScrollerKnob\n"));
 		if (sender == m_vScrollbar) {
 			m_VCurrentScroll = lrintf(newValue * m_VMaxScroll);
 			_setVScrollbarValues();
@@ -416,20 +420,15 @@ void AP_CocoaFrameImpl::_createDocView(GR_Graphics* &pG)
 	XAP_Frame*	pFrame = getFrame();
 	NSView*		docArea = [_getController() getMainView];
 	NSArray*	docAreaSubviews;
-	
-	docAreaSubviews = [docArea subviews];
-	if ([docAreaSubviews count] != 0) {
-		NSEnumerator *enumerator = [docAreaSubviews objectEnumerator];
-		NSView* aSubview;
-	
-		while ((aSubview = [enumerator nextObject])) {
-			[aSubview removeFromSuperviewWithoutNeedingDisplay];
-		}
-		
-		m_hScrollbar = NULL;
-		m_vScrollbar = NULL;
-		m_docAreaGRView = NULL;
-	}
+
+    docAreaSubviews = [docArea subviews];
+    if ([docAreaSubviews count] > 0) {
+        for (NSView *aSubview in [docAreaSubviews copy])
+            [aSubview removeFromSuperviewWithoutNeedingDisplay];
+        m_hScrollbar = NULL;
+        m_vScrollbar = NULL;
+        m_docAreaGRView = NULL;
+    }
 	NSRect frame = [docArea bounds];
 	NSRect controlFrame;
 	
@@ -629,7 +628,7 @@ bool AP_CocoaFrameImpl::_graphicsUpdateCB(NSRect * aRect, GR_CocoaCairoGraphics
 		rClip.top = (UT_sint32)rint(pG->tluD(aRect->origin.y));
 		rClip.width = (UT_sint32)rint(pG->tluD(aRect->size.width));
 		rClip.height = (UT_sint32)rint(pG->tluD(aRect->size.height));
-		xxx_UT_DEBUGMSG(("Cocoa in frame expose painting area:  left=%d, top=%d, width=%d, height=%d\n", rClip.left, rClip.top, rClip.width, rClip.height));
+		UT_DEBUGMSG(("Cocoa in frame expose painting area:  left=%d, top=%d, width=%d, height=%d\n", rClip.left, rClip.top, rClip.width, rClip.height));
 		pView->draw(&rClip);
 	}
 	else
