@@ -94,7 +94,7 @@ static void s_line_bottom(GtkWidget *widget, gpointer data )
 	dlg->event_previewExposed();
 }
 
-static gboolean s_preview_exposed(GtkWidget * widget, gpointer /* data */, AP_UnixDialog_Border_Shading * dlg)
+static gboolean s_preview_draw(GtkWidget * widget, gpointer /* data */, AP_UnixDialog_Border_Shading * dlg)
 {
 	UT_return_val_if_fail(widget && dlg, FALSE);
 	dlg->event_previewExposed();
@@ -107,6 +107,7 @@ static gboolean s_on_shading_enable_clicked(GtkWidget 		*button,
 	AP_UnixDialog_Border_Shading *dlg = static_cast<AP_UnixDialog_Border_Shading *>(data);
 	UT_return_val_if_fail (button && dlg, FALSE);
 	dlg->event_shadingPatternChange();
+	return FALSE;
 }
 
 /*!
@@ -127,7 +128,7 @@ static gboolean s_on_border_color_clicked (GtkWidget 		*button,
 
 	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
 	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
-	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION (gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG (colordlg)));
 	gtk_color_selection_set_has_palette (colorsel, TRUE);
 	
 	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
@@ -183,7 +184,7 @@ static gboolean s_on_shading_color_clicked (GtkWidget 		*button,
 
 	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
 	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
-	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION (gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG (colordlg)));
 	gtk_color_selection_set_has_palette (colorsel, TRUE);
 	
 	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
@@ -269,12 +270,12 @@ void AP_UnixDialog_Border_Shading::runModeless(XAP_Frame * pFrame)
 
 	// Populate the window's data items
 	_populateWindowData();
-	_connectSignals();
+//	_connectSignals(); // last call runs setSensitivity which calls _connectSignals
 	abiSetupModelessDialog(GTK_DIALOG(m_windowMain), pFrame, this, BUTTON_CLOSE);
 	
 	// *** this is how we add the gc for Column Preview ***
 	// attach a new graphics context to the drawing area
-	UT_return_if_fail(m_wPreviewArea && m_wPreviewArea->window);
+	UT_return_if_fail(m_wPreviewArea && gtk_widget_get_window(m_wPreviewArea));
 
 	// make a new Unix GC
 	DELETEP (m_pPreviewWidget);
@@ -285,13 +286,15 @@ void AP_UnixDialog_Border_Shading::runModeless(XAP_Frame * pFrame)
 	// Todo: we need a good widget to query with a probable
 	// Todo: non-white (i.e. gray, or a similar bgcolor as our parent widget)
 	// Todo: background. This should be fine
-	m_pPreviewWidget->init3dColors(m_wPreviewArea->style);
+	m_pPreviewWidget->init3dColors(gtk_widget_get_style_context(m_wPreviewArea));
 
 	// let the widget materialize
 
+	GtkAllocation alloc;
+	gtk_widget_get_allocation(m_wPreviewArea, &alloc);
 	_createPreviewFromGC(m_pPreviewWidget,
-						 static_cast<UT_uint32>(m_wPreviewArea->allocation.width),
-						 static_cast<UT_uint32>(m_wPreviewArea->allocation.height));	
+						 static_cast<UT_uint32>(alloc.width),
+						 static_cast<UT_uint32>(alloc.height));	
 	
 	m_pBorderShadingPreview->draw();
 
@@ -299,10 +302,13 @@ void AP_UnixDialog_Border_Shading::runModeless(XAP_Frame * pFrame)
 	UT_DEBUGMSG(("========================= End the unModeless \n"));
 }
 
-void AP_UnixDialog_Border_Shading::setSensitivity(bool bSens)
+void AP_UnixDialog_Border_Shading::setSensitivity(bool /* bSens */)
 {
 //	UT_DEBUGMSG(("========================= Set the sensitivity \n"));
 
+	if (m_iLineLeftConnect == 0)
+		_connectSignals();// avoids some criticals
+		
 	XAP_GtkSignalBlocker b1(G_OBJECT(m_wLineLeft), m_iLineLeftConnect);
 	gtk_toggle_button_set_active((GtkToggleButton*)m_wLineLeft, getLeftToggled() ? TRUE: FALSE);
 
@@ -330,9 +336,11 @@ void AP_UnixDialog_Border_Shading::event_previewExposed(void)
 
 void AP_UnixDialog_Border_Shading::_setShadingEnable(bool enable)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setting shading enable: \n"));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setting shading enable: \n"));
 
+	gtk_widget_set_sensitive(m_wShadingOffsetLabel, enable);
 	gtk_widget_set_sensitive(m_wShadingOffset, enable);
+	gtk_widget_set_sensitive(m_wShadingColorLabel, enable);
 	gtk_widget_set_sensitive(m_wShadingColorButton, enable);
 
 	XAP_GtkSignalBlocker b1(G_OBJECT(m_wShadingEnable), m_iShadingEnableConnect);
@@ -341,7 +349,7 @@ void AP_UnixDialog_Border_Shading::_setShadingEnable(bool enable)
 
 void AP_UnixDialog_Border_Shading::setBorderThicknessInGUI(UT_UTF8String & sThick)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the border thickness in the GUI: %s \n", sThick.utf8_str()));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the border thickness in the GUI: %s \n", sThick.utf8_str()));
 
 	guint closest = _findClosestThickness(sThick.utf8_str());
 	XAP_GtkSignalBlocker b(G_OBJECT(m_wBorderThickness),m_iBorderThicknessConnect);
@@ -350,10 +358,10 @@ void AP_UnixDialog_Border_Shading::setBorderThicknessInGUI(UT_UTF8String & sThic
 
 void AP_UnixDialog_Border_Shading::setBorderStyleInGUI(UT_UTF8String & sStyle)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the border style in the GUI: %s \n", sStyle.utf8_str()));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the border style in the GUI: %s \n", sStyle.utf8_str()));
 
 	PP_PropertyMap::TypeLineStyle style = PP_PropertyMap::linestyle_type(sStyle.utf8_str());
-	guint index = (guint)style - 1;
+	gint index = style - 1;
 
 	if (index >= 0)
 	{
@@ -364,7 +372,7 @@ void AP_UnixDialog_Border_Shading::setBorderStyleInGUI(UT_UTF8String & sStyle)
 
 void AP_UnixDialog_Border_Shading::setBorderColorInGUI(UT_RGBColor clr)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the border color in the GUI: %d|%d|%d \n", clr.m_red, clr.m_grn, clr.m_blu));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the border color in the GUI: %d|%d|%d \n", clr.m_red, clr.m_grn, clr.m_blu));
 
 	GdkColor* color = UT_UnixRGBColorToGdkColor(clr);
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (m_wBorderColorButton), color);
@@ -373,7 +381,7 @@ void AP_UnixDialog_Border_Shading::setBorderColorInGUI(UT_RGBColor clr)
 
 void AP_UnixDialog_Border_Shading::setShadingColorInGUI(UT_RGBColor clr)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the shading color in the GUI: %d|%d|%d \n", clr.m_red, clr.m_grn, clr.m_blu));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the shading color in the GUI: %d|%d|%d \n", clr.m_red, clr.m_grn, clr.m_blu));
 
 	GdkColor* color = UT_UnixRGBColorToGdkColor(clr);
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (m_wShadingColorButton), color);
@@ -382,7 +390,7 @@ void AP_UnixDialog_Border_Shading::setShadingColorInGUI(UT_RGBColor clr)
 
 void AP_UnixDialog_Border_Shading::setShadingPatternInGUI(UT_UTF8String & sPattern)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the shading pattern in the GUI: %s \n", sPattern.utf8_str()));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the shading pattern in the GUI: %s \n", sPattern.utf8_str()));
 
 	// 8/8/2010 Maleesh - TODO: Change this, when there are more shading patterns.
 	bool shading_enabled = !(sPattern == BORDER_SHADING_SHADING_DISABLE);
@@ -391,7 +399,7 @@ void AP_UnixDialog_Border_Shading::setShadingPatternInGUI(UT_UTF8String & sPatte
 
 void AP_UnixDialog_Border_Shading::setShadingOffsetInGUI(UT_UTF8String & sOffset)
 {
-	UT_DEBUGMSG(("Maleesh =============== Setup the shading offset in the GUI: %s \n", sOffset.utf8_str()));
+	xxx_UT_DEBUGMSG(("Maleesh =============== Setup the shading offset in the GUI: %s \n", sOffset.utf8_str()));
 
 	guint closest = _findClosestOffset(sOffset.utf8_str());
 	XAP_GtkSignalBlocker b(G_OBJECT(m_wShadingOffset),m_iShadingOffsetConnect);
@@ -450,7 +458,7 @@ void AP_UnixDialog_Border_Shading::event_ShadingOffsetChanged(void)
 
 void AP_UnixDialog_Border_Shading::event_shadingPatternChange(void)
 {
-	UT_DEBUGMSG(("========================= Changed the state of the cb \n"));
+	xxx_UT_DEBUGMSG(("========================= Changed the state of the cb \n"));
 
 	// 8/8/2010 Maleesh - TODO: Change this, when there are more shading patterns.
 	gboolean bEnable = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_wShadingEnable));
@@ -473,7 +481,7 @@ void AP_UnixDialog_Border_Shading::activate(void)
 	ConstructWindowName();
 	gtk_window_set_title (GTK_WINDOW (m_windowMain), m_WindowName);
 	setAllSensitivities();
-	gdk_window_raise (m_windowMain->window);
+	gdk_window_raise (gtk_widget_get_window(m_windowMain));
 }
 
 void AP_UnixDialog_Border_Shading::notifyActiveFrame(XAP_Frame */*pFrame*/)
@@ -513,12 +521,6 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 	m_wLineRight 	= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderRight"));
 	m_wLineBottom 	= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderBottom"));
 	
-	// the toggle buttons created by GtkBuilder already contain a label, remove that, so we can add a pixmap as a child
-	gtk_container_remove(GTK_CONTAINER(m_wLineTop), gtk_bin_get_child(GTK_BIN(m_wLineTop)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineLeft), gtk_bin_get_child(GTK_BIN(m_wLineLeft)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineRight), gtk_bin_get_child(GTK_BIN(m_wLineRight)));
-	gtk_container_remove(GTK_CONTAINER(m_wLineBottom), gtk_bin_get_child(GTK_BIN(m_wLineBottom)));
-	
 	// place some nice pixmaps on our border toggle buttons
 	label_button_with_abi_pixmap(m_wLineTop, "tb_LineTop_xpm");
 	label_button_with_abi_pixmap(m_wLineLeft, "tb_LineLeft_xpm");
@@ -543,8 +545,10 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 	localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lblBorderStyle")), pSS, AP_STRING_ID_DLG_BorderShading_Border_Style);
 
 	localizeLabelMarkup(GTK_WIDGET(gtk_builder_get_object(builder, "lbShading")), pSS, AP_STRING_ID_DLG_BorderShading_Shading);
-	localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lbShadingColor")), pSS, AP_STRING_ID_DLG_BorderShading_Shading_Color);
-	localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lblShadingOffset")), pSS, AP_STRING_ID_DLG_BorderShading_Offset);
+	m_wShadingColorLabel = GTK_WIDGET(gtk_builder_get_object(builder, "lbShadingColor"));
+	localizeLabel(m_wShadingColorLabel, pSS, AP_STRING_ID_DLG_BorderShading_Shading_Color);
+	m_wShadingOffsetLabel = GTK_WIDGET(gtk_builder_get_object(builder, "lblShadingOffset"));
+	localizeLabel(m_wShadingOffsetLabel, pSS, AP_STRING_ID_DLG_BorderShading_Offset);
 
 	localizeLabelMarkup(GTK_WIDGET(gtk_builder_get_object(builder, "lbPreview")), pSS, AP_STRING_ID_DLG_FormatTable_Preview);
 
@@ -555,45 +559,42 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 // Border Thickness Option menu
 // 
 	m_wBorderThickness = GTK_WIDGET(gtk_builder_get_object(builder, "omBorderThickness"));
-	GtkComboBox *combo = GTK_COMBO_BOX(m_wBorderThickness);
-	XAP_makeGtkComboBoxText(combo, G_TYPE_NONE);
-	gtk_combo_box_append_text(combo, "1/2 pt");
-	gtk_combo_box_append_text(combo, "3/4 pt");
-	gtk_combo_box_append_text(combo, "1 pt");
-	gtk_combo_box_append_text(combo, "1 1/2 pt");
-	gtk_combo_box_append_text(combo, "2 1/4 pt");
-	gtk_combo_box_append_text(combo, "3 pt");
-	gtk_combo_box_append_text(combo, "4 1/2 pt");
-	gtk_combo_box_append_text(combo, "6 pt");
-	gtk_combo_box_set_active(combo, 0);
+	GtkComboBoxText *combo = GTK_COMBO_BOX_TEXT(m_wBorderThickness);
+	gtk_combo_box_text_append_text(combo, "1/2 pt");
+	gtk_combo_box_text_append_text(combo, "3/4 pt");
+	gtk_combo_box_text_append_text(combo, "1 pt");
+	gtk_combo_box_text_append_text(combo, "1 1/2 pt");
+	gtk_combo_box_text_append_text(combo, "2 1/4 pt");
+	gtk_combo_box_text_append_text(combo, "3 pt");
+	gtk_combo_box_text_append_text(combo, "4 1/2 pt");
+	gtk_combo_box_text_append_text(combo, "6 pt");
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
 
 //
 // Border Style Option menu
 //
 	m_wBorderStyle = GTK_WIDGET(gtk_builder_get_object(builder, "cmbBorderStyle"));
-	GtkComboBox *combo_style = GTK_COMBO_BOX(m_wBorderStyle);
-	XAP_makeGtkComboBoxText(combo_style, G_TYPE_NONE);
-	gtk_combo_box_append_text(combo_style, "None");
-	gtk_combo_box_append_text(combo_style, "Solid line");
-	gtk_combo_box_append_text(combo_style, "Dashed line");
-	gtk_combo_box_append_text(combo_style, "Dotted line");
-	gtk_combo_box_set_active(combo, 0);
+	GtkComboBoxText *combo_style = GTK_COMBO_BOX_TEXT(m_wBorderStyle);
+	gtk_combo_box_text_append_text(combo_style, "None");
+	gtk_combo_box_text_append_text(combo_style, "Solid line");
+	gtk_combo_box_text_append_text(combo_style, "Dashed line");
+	gtk_combo_box_text_append_text(combo_style, "Dotted line");
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo_style), 0);
 
 //
 // Shading offset Option menu
 //
 	m_wShadingOffset = GTK_WIDGET(gtk_builder_get_object(builder, "cmbShadingOffset"));
-	GtkComboBox *combo_offset = GTK_COMBO_BOX(m_wShadingOffset);
-	XAP_makeGtkComboBoxText(combo_offset, G_TYPE_NONE);
-	gtk_combo_box_append_text(combo_offset, "1/2 pt");
-	gtk_combo_box_append_text(combo_offset, "3/4 pt");
-	gtk_combo_box_append_text(combo_offset, "1 pt");
-	gtk_combo_box_append_text(combo_offset, "1 1/2 pt");
-	gtk_combo_box_append_text(combo_offset, "2 1/4 pt");
-	gtk_combo_box_append_text(combo_offset, "3 pt");
-	gtk_combo_box_append_text(combo_offset, "4 1/2 pt");
-	gtk_combo_box_append_text(combo_offset, "6 pt");
-	gtk_combo_box_set_active(combo_offset, 0);
+	GtkComboBoxText *combo_offset = GTK_COMBO_BOX_TEXT(m_wShadingOffset);
+	gtk_combo_box_text_append_text(combo_offset, "1/2 pt");
+	gtk_combo_box_text_append_text(combo_offset, "3/4 pt");
+	gtk_combo_box_text_append_text(combo_offset, "1 pt");
+	gtk_combo_box_text_append_text(combo_offset, "1 1/2 pt");
+	gtk_combo_box_text_append_text(combo_offset, "2 1/4 pt");
+	gtk_combo_box_text_append_text(combo_offset, "3 pt");
+	gtk_combo_box_text_append_text(combo_offset, "4 1/2 pt");
+	gtk_combo_box_text_append_text(combo_offset, "6 pt");
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo_offset), 0);
 
 	// add the apply and ok buttons to the dialog
 	m_wCloseButton = GTK_WIDGET(gtk_builder_get_object(builder, "btClose"));
@@ -620,11 +621,11 @@ static void s_delete_clicked(GtkWidget * widget,
 
 void AP_UnixDialog_Border_Shading::_connectSignals(void)
 {
-	g_signal_connect(GTK_OBJECT(m_windowMain),
+	g_signal_connect(G_OBJECT(m_windowMain),
 							"destroy",
 							G_CALLBACK(s_destroy_clicked),
 							reinterpret_cast<gpointer>(this));
-	g_signal_connect(GTK_OBJECT(m_windowMain),
+	g_signal_connect(G_OBJECT(m_windowMain),
 							"delete_event",
 							G_CALLBACK(s_delete_clicked),
 							reinterpret_cast<gpointer>(this));
@@ -670,8 +671,8 @@ void AP_UnixDialog_Border_Shading::_connectSignals(void)
 							reinterpret_cast<gpointer>(this));
 						   
 	g_signal_connect(G_OBJECT(m_wPreviewArea),
-							"expose_event",
-							G_CALLBACK(s_preview_exposed),
+							"draw",
+							G_CALLBACK(s_preview_draw),
 							reinterpret_cast<gpointer>(this));
 
 	m_iShadingOffsetConnect = g_signal_connect(G_OBJECT(m_wShadingOffset),
