@@ -129,7 +129,7 @@ GtkWidget * AP_UnixStatusBar::createWidget(void)
 	UT_ASSERT(!m_wStatusBar);
 	
 	// probably should make this into an event box (if we want the user to be able to interact with the status bar)
-	m_wStatusBar = gtk_hbox_new(FALSE, 0);
+	m_wStatusBar = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	gtk_widget_show(m_wStatusBar);
 
@@ -178,7 +178,6 @@ GtkWidget * AP_UnixStatusBar::createWidget(void)
 			gtk_box_pack_start(GTK_BOX(m_wStatusBar), pStatusBarElement, TRUE, TRUE, 0);
 			GtkWidget *  pProgress= gtk_progress_bar_new();
 			gtk_container_add(GTK_CONTAINER(pStatusBarElement),pProgress);
-			gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(pProgress),GTK_PROGRESS_LEFT_TO_RIGHT);
 			gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR(pProgress),0.01);
 
 			gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(pProgress),0.0);
