@@ -24,11 +24,11 @@
 #include "xap_Win32DialogHelper.h"
 #include "xap_Win32PreviewWidget.h"
 #include "xap_Frame.h"
-
+#include "xap_Win32DialogBase.h"
 
 /*****************************************************************/
 
-class AP_Win32Dialog_Lists: public AP_Dialog_Lists, XAP_Win32Dialog
+class ABI_EXPORT AP_Win32Dialog_Lists: public AP_Dialog_Lists, XAP_Win32Dialog, public XAP_Win32DialogBase
 {
 public:
 	AP_Win32Dialog_Lists(XAP_DialogFactory * pDlgFactory, XAP_Dialog_Id id);
