@@ -115,11 +115,11 @@ void AP_Frame::quickZoom(UT_uint32 iZoom)
 		setXScrollRange();
 		if(pTop && !pTop->isHidden())
 		{
-			pTop->draw(NULL);
+			pTop->queueDraw();
 		}
 		if(pLeft && !pLeft->isHidden())
 		{
-			pLeft->draw(NULL);
+			pLeft->queueDraw();
 		}
 //
 // Redraw the entire screen
@@ -710,12 +710,12 @@ UT_Error AP_Frame::_showDocument(UT_uint32 iZoom)
 		if ( static_cast<AP_FrameData*>(m_pData)->m_pTopRuler )
 		{
 			static_cast<AP_FrameData*>(m_pData)->m_pTopRuler->setZoom(iZoom);
-			static_cast<AP_FrameData*>(m_pData)->m_pTopRuler->draw(NULL);
+			static_cast<AP_FrameData*>(m_pData)->m_pTopRuler->queueDraw();
 		}
 		if ( static_cast<AP_FrameData*>(m_pData)->m_pLeftRuler )
 		{
 			static_cast<AP_FrameData*>(m_pData)->m_pLeftRuler->setZoom(iZoom);
-			static_cast<AP_FrameData*>(m_pData)->m_pLeftRuler->draw(NULL);
+			static_cast<AP_FrameData*>(m_pData)->m_pLeftRuler->queueDraw();
 		}
 	}
 	if(isStatusBarShown())
