@@ -46,6 +46,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_StylesLocked);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_ScriptsActive);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_SomethingSelected);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_HyperlinkOK);
+Defun_EV_GetMenuItemState_Fn(ap_GetState_RDFAnchorOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_Spelling);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_ColumnsActive);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_AutoRevision);
@@ -64,6 +65,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_FmtHdrFtr);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_BreakOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_TOCOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_BookmarkOK);
+Defun_EV_GetMenuItemState_Fn(ap_GetState_xmlidOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_TextToTableOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTOC);
@@ -85,6 +87,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Lists);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_MailMerge);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InsTextBox);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_AnnotationJumpOK);
+Defun_EV_GetMenuItemState_Fn(ap_GetState_ToggleRDFAnchorHighlight);
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Toolbar);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Recent);
