@@ -107,8 +107,12 @@ void TOC_Listener::_commitTOCData()
 
 TOC_Listener::TOC_Listener(PD_Document * pDocument,
 			   IE_TOCHelper * toc)
-  : mInHeading(0), mHeadingText(""), mHeadingLevel(0),
-    mDocument(pDocument), mTOC(toc), mHeadingPos(0)
+  : mInHeading(0), 
+    mHeadingText(""), 
+    mHeadingLevel(0),
+    mHeadingPos(0),
+    mDocument(pDocument), 
+    mTOC(toc)
 {
 }
   
@@ -297,7 +301,7 @@ UT_UTF8String IE_TOCHelper::getNthTOCEntry(int nth, int * out_level) const
   return *mTOCStrings.getNthItem(nth);
 }
 
-bool IE_TOCHelper::getNthTOCEntryPos(int nth, PT_DocPosition &pos)
+bool IE_TOCHelper::getNthTOCEntryPos(int nth, PT_DocPosition &pos) const
 {
 	UT_return_val_if_fail(nth < getNumTOCEntries(), false);
 
