@@ -31,6 +31,8 @@
 #include "ie_impexp_RTF.h"
 #include "ie_exp_RTF.h"
 #include "pd_Document.h"
+#include "pd_DocumentRDF.h"
+#include "pd_RDFSupport.h"
 #include "pp_AttrProp.h"
 #include "pp_Property.h"
 #include "pp_Revision.h"
@@ -41,11 +43,15 @@
 #include "pd_Style.h"
 #include "gr_Graphics.h"
 #include "ut_rand.h"
+#include "ut_std_string.h"
+#include "pl_ListenerCoupleCloser.h"
 
 #include "wv.h" //for wvLIDToCodePageConverter
 #include "xap_EncodingManager.h"
 #include "ut_debugmsg.h"
 
+#include <sstream>
+
 /*****************************************************************/
 /*****************************************************************/
 
@@ -249,10 +255,12 @@ UT_Error IE_Exp_RTF::_writeDocumentLocal(bool bSkipHeader)
 	m_pListenerWriteDoc = new s_RTF_ListenerWriteDoc(getDoc(),this, (getDocRange()!=NULL), hasBlock);
 	if (!m_pListenerWriteDoc)
 		return UT_IE_NOMEMORY;
+    PL_ListenerCoupleCloser* pCloser = new PL_ListenerCoupleCloser();
 	if (getDocRange())
-		getDoc()->tellListenerSubset(m_pListenerWriteDoc,getDocRange());
+		getDoc()->tellListenerSubset(m_pListenerWriteDoc,getDocRange(),pCloser);
 	else
 		getDoc()->tellListener(m_pListenerWriteDoc);
+    DELETEP(pCloser);
 	DELETEP(m_pListenerWriteDoc);
 
 	// write any rtf trailer matter
@@ -559,6 +567,12 @@ void IE_Exp_RTF::_rtf_fontname(const char * szFontName)
 	return;
 }
 
+
+void IE_Exp_RTF::_rtf_chardata(const std::string& buf)
+{
+    _rtf_chardata( buf.c_str(), buf.length() );
+}
+
 /*
  * I'm increasingly suspicious of this function. It seems to be
  * being used to output PCDATA (like stylesheet names). For 
@@ -1077,7 +1091,48 @@ bool IE_Exp_RTF::_write_rtf_header(void)
 	{
 		_rtf_keyword("revisions");
 	}
-	
+
+    //
+    // export the RDF too
+    //
+    {
+        _rtf_open_brace();
+		_rtf_keyword("*");
+		_rtf_keyword("rdf");
+        if( getDocRange() )
+        {
+            PD_DocumentRDFHandle rdf = getDoc()->getDocumentRDF();
+            std::list< std::string > xmlids;
+            rdf->addRelevantIDsForRange( xmlids, getDocRange() );
+            PD_RDFModelHandle subm = rdf->createRestrictedModelForXMLIDs( xmlids );
+            std::string rdfxml = toRDFXML( subm );
+            _rtf_chardata( s_escapeXMLString(rdfxml) );
+
+            
+            // std::stringstream countss;
+            // countss << subm->size();
+            // _rtf_chardata( countss.str() );
+            
+            // PD_RDFModelIterator iter = subm->begin();
+            // PD_RDFModelIterator    e = subm->end();
+            // for( ; iter != e; ++iter )
+            // {
+            //     const PD_RDFStatement& st = *iter;
+            //     _rtf_open_brace();
+            //     _rtf_keyword("*");
+            //     _rtf_keyword("triple");
+            //     std::stringstream ss;
+            //     st.getSubject().write( ss );
+            //     st.getPredicate().write( ss );
+            //     st.getObject().write( ss );
+            //     _rtf_chardata( ss.str() );
+            //     _rtf_close_brace();
+            // }
+            
+        }
+		_rtf_close_brace();
+    }
+    
 	return (m_error == 0);
 }
 
@@ -3260,6 +3315,36 @@ bool IE_Exp_RTF::s_escapeString(UT_UTF8String &sOutStr,
 	return IE_Exp_RTF::s_escapeString(sOutStr, sUCS4InStr, iAltChars);
 }
 
+bool IE_Exp_RTF::s_escapeString( std::string& outStr, const std::string& inStr, 
+                                 UT_uint32 iAltChars )
+{
+    UT_UTF8String sOutStr;
+    bool ret = s_escapeString( sOutStr, inStr.c_str(), inStr.length(), iAltChars );
+    outStr = sOutStr.utf8_str();
+    return ret;
+}
+
+std::string IE_Exp_RTF::s_escapeString( const std::string& inStr, UT_uint32 iAltChars )
+{
+    UT_UTF8String sOutStr;
+    bool ret = s_escapeString( sOutStr, inStr.c_str(), inStr.length(), iAltChars );
+    return (std::string)sOutStr.utf8_str();
+}
+
+
+std::string IE_Exp_RTF::s_escapeXMLString( const std::string& inStr )
+{
+    //
+    // &7d; is }
+    //
+    std::string s = inStr;
+    s = replace_all( s, "&7d;",  "&7d;&7d;" );
+    s = replace_all( s, "}",  "&7d;" );
+//    s = s_escapeString( s );
+    return s;
+}
+
+
 
 _rtf_font_info::_rtf_font_info()
 {
