@@ -147,6 +147,7 @@ protected:
 	void				_rtf_semi(void);
 	void				_rtf_fontname(const char * szFontName);
 	void				_rtf_chardata(const char * pbuf, UT_uint32 buflen);
+	void				_rtf_chardata(const std::string& buf);
 	void				_rtf_pcdata(UT_UTF8String &sPCData, bool bSupplyUC=false, UT_uint32 iAltChars=1);
 	void				_rtf_pcdata(const char * szPCData, bool bSupplyUC=false, UT_uint32 iAltChars=1);
 	void				_rtf_nl(void);
@@ -197,6 +198,10 @@ protected:
 	                           UT_uint32 iAltChars);
 	static bool s_escapeString(UT_UTF8String &sOutStr, const char * szInStr,
                                UT_uint32 iSize, UT_uint32 iAltChars);
+	static bool s_escapeString( std::string& outStr, const std::string& inStr, 
+	                           UT_uint32 iAltChars = 1 );
+	static std::string s_escapeString( const std::string& inStr, UT_uint32 iAltChars = 1 );
+    static std::string s_escapeXMLString( const std::string& inStr );
 
 	s_RTF_ListenerWriteDoc *	m_pListenerWriteDoc;
 	UT_Vector					m_vecColors;			/* vector of "const char * szColor" */
