@@ -557,11 +557,15 @@ class ABI_EXPORT ABI_RTF_Annotation
 	virtual ~ABI_RTF_Annotation() {}
 	UT_sint32          m_iAnnNumber;
 	UT_UTF8String      m_sAuthor;
+	UT_UTF8String      m_sAuthorId;
 	UT_UTF8String      m_sDate;
 	UT_UTF8String      m_sTitle;
 	pf_Frag *          m_pInsertFrag;
 	PT_DocPosition     m_Annpos;
 	UT_sint32          m_iRTFLevel;
+	static UT_sint32   newNumber();
+private:
+	static UT_sint32 sAnnotationNumber;
 };
 
 // The importer/reader for Rich Text Format files
@@ -653,6 +657,7 @@ private:
 	bool ReadCharFromFileWithCRLF(unsigned char* pCh);
 	bool ReadCharFromFile(unsigned char* pCh);
 	bool ReadContentFromFile(UT_UTF8String & str);
+	std::string s_unEscapeXMLString();
 	UT_UCS4Char ReadHexChar(void);
 	bool SkipBackChar(unsigned char ch);
 	bool ReadKeyword(unsigned char* pKeyword, UT_sint32* pParam, 
@@ -685,6 +690,7 @@ private:
 	bool PostProcessAndValidatePanose(UT_UTF8String &Panose);
 	bool ReadRevisionTable();
 	void setEncoding();  
+	bool ReadRDFTriples();
 public:
 	bool HandlePicture();
 	void clearImageName(void)
@@ -752,6 +758,7 @@ private:
 	bool HandleRDFAnchor (RTFBookmarkType type);
 	bool HandleListTag(long id);
 
+	bool HandleDeltaMoveID();
 	bool HandleRevisedText(PP_RevisionType eType, UT_uint32 iId);
 	bool HandleRevisedTextTimestamp(UT_uint32 iDttm);
 
@@ -809,6 +816,8 @@ private:
  private:
 
 	void           HandleNote();
+	void           StartAnnotation();
+	void           EndAnnotation();
 	void           HandleAnnotation();
 	void           HandleNoteReference();
 // Shape handlers in ie_imp_RTFObjectsAndPicts.cpp
@@ -987,6 +996,12 @@ private:
 	bool                  m_bFrameTextBox;
 	bool                  m_bParaActive;
 	bool                  m_bCellActive;
+
+	std::string           m_ctMoveID;
+	
+	PD_XMLIDCreatorHandle  m_XMLIDCreatorHandle;
+	std::map< std::string, std::string > m_rdfAnchorCloseXMLIDs;
+	
 };
 
 #endif /* IE_IMP_RTF_H */
